/* -------------------------------------------
     This file was created with csUtility.java

    Unicode mapping table generated from java mapping and UnicodeData.txt

#    Name:     Cp866 to Unicode table
#    Unicode version: Java 1.3

 * The contents of this file are subject to the Interbase Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy
 * of the License at http://www.Inprise.com/IPL.html
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code was created by Inprise Corporation
 * and its predecessors. Portions created by Inprise Corporation are
 * Copyright (C) Inprise Corporation.
 *
 * All Rights Reserved.
 * Contributor(s): Blas Rodriguez Somoza.
   -------------------------------------------- */
static const USHORT to_unicode_map[256] = {
/* 00 */  0x0000 /*                                          NULL */,
/* 01 */  0x0001 /*                              START OF HEADING */,
/* 02 */  0x0002 /*                                 START OF TEXT */,
/* 03 */  0x0003 /*                                   END OF TEXT */,
/* 04 */  0x0004 /*                           END OF TRANSMISSION */,
/* 05 */  0x0005 /*                                       ENQUIRY */,
/* 06 */  0x0006 /*                                   ACKNOWLEDGE */,
/* 07 */  0x0007 /*                                          BELL */,
/* 08 */  0x0008 /*                                     BACKSPACE */,
/* 09 */  0x0009 /*                          CHARACTER TABULATION */,
/* 0A */  0x000A /*                                LINE FEED (LF) */,
/* 0B */  0x000B /*                               LINE TABULATION */,
/* 0C */  0x000C /*                                FORM FEED (FF) */,
/* 0D */  0x000D /*                          CARRIAGE RETURN (CR) */,
/* 0E */  0x000E /*                                     SHIFT OUT */,
/* 0F */  0x000F /*                                      SHIFT IN */,
/* 10 */  0x0010 /*                              DATA LINK ESCAPE */,
/* 11 */  0x0011 /*                            DEVICE CONTROL ONE */,
/* 12 */  0x0012 /*                            DEVICE CONTROL TWO */,
/* 13 */  0x0013 /*                          DEVICE CONTROL THREE */,
/* 14 */  0x0014 /*                           DEVICE CONTROL FOUR */,
/* 15 */  0x0015 /*                          NEGATIVE ACKNOWLEDGE */,
/* 16 */  0x0016 /*                              SYNCHRONOUS IDLE */,
/* 17 */  0x0017 /*                     END OF TRANSMISSION BLOCK */,
/* 18 */  0x0018 /*                                        CANCEL */,
/* 19 */  0x0019 /*                                 END OF MEDIUM */,
/* 1A */  0x001A /*                                    SUBSTITUTE */,
/* 1B */  0x001B /*                                        ESCAPE */,
/* 1C */  0x001C /*                    INFORMATION SEPARATOR FOUR */,
/* 1D */  0x001D /*                   INFORMATION SEPARATOR THREE */,
/* 1E */  0x001E /*                     INFORMATION SEPARATOR TWO */,
/* 1F */  0x001F /*                     INFORMATION SEPARATOR ONE */,
/* 20 */  0x0020 /*                                         SPACE */,
/* 21 */  0x0021 /*                              EXCLAMATION MARK */,
/* 22 */  0x0022 /*                                QUOTATION MARK */,
/* 23 */  0x0023 /*                                   NUMBER SIGN */,
/* 24 */  0x0024 /*                                   DOLLAR SIGN */,
/* 25 */  0x0025 /*                                  PERCENT SIGN */,
/* 26 */  0x0026 /*                                     AMPERSAND */,
/* 27 */  0x0027 /*                                    APOSTROPHE */,
/* 28 */  0x0028 /*                              LEFT PARENTHESIS */,
/* 29 */  0x0029 /*                             RIGHT PARENTHESIS */,
/* 2A */  0x002A /*                                      ASTERISK */,
/* 2B */  0x002B /*                                     PLUS SIGN */,
/* 2C */  0x002C /*                                         COMMA */,
/* 2D */  0x002D /*                                  HYPHEN-MINUS */,
/* 2E */  0x002E /*                                     FULL STOP */,
/* 2F */  0x002F /*                                       SOLIDUS */,
/* 30 */  0x0030 /*                                    DIGIT ZERO */,
/* 31 */  0x0031 /*                                     DIGIT ONE */,
/* 32 */  0x0032 /*                                     DIGIT TWO */,
/* 33 */  0x0033 /*                                   DIGIT THREE */,
/* 34 */  0x0034 /*                                    DIGIT FOUR */,
/* 35 */  0x0035 /*                                    DIGIT FIVE */,
/* 36 */  0x0036 /*                                     DIGIT SIX */,
/* 37 */  0x0037 /*                                   DIGIT SEVEN */,
/* 38 */  0x0038 /*                                   DIGIT EIGHT */,
/* 39 */  0x0039 /*                                    DIGIT NINE */,
/* 3A */  0x003A /*                                         COLON */,
/* 3B */  0x003B /*                                     SEMICOLON */,
/* 3C */  0x003C /*                                LESS-THAN SIGN */,
/* 3D */  0x003D /*                                   EQUALS SIGN */,
/* 3E */  0x003E /*                             GREATER-THAN SIGN */,
/* 3F */  0x003F /*                                 QUESTION MARK */,
/* 40 */  0x0040 /*                                 COMMERCIAL AT */,
/* 41 */  0x0041 /*                        LATIN CAPITAL LETTER A */,
/* 42 */  0x0042 /*                        LATIN CAPITAL LETTER B */,
/* 43 */  0x0043 /*                        LATIN CAPITAL LETTER C */,
/* 44 */  0x0044 /*                        LATIN CAPITAL LETTER D */,
/* 45 */  0x0045 /*                        LATIN CAPITAL LETTER E */,
/* 46 */  0x0046 /*                        LATIN CAPITAL LETTER F */,
/* 47 */  0x0047 /*                        LATIN CAPITAL LETTER G */,
/* 48 */  0x0048 /*                        LATIN CAPITAL LETTER H */,
/* 49 */  0x0049 /*                        LATIN CAPITAL LETTER I */,
/* 4A */  0x004A /*                        LATIN CAPITAL LETTER J */,
/* 4B */  0x004B /*                        LATIN CAPITAL LETTER K */,
/* 4C */  0x004C /*                        LATIN CAPITAL LETTER L */,
/* 4D */  0x004D /*                        LATIN CAPITAL LETTER M */,
/* 4E */  0x004E /*                        LATIN CAPITAL LETTER N */,
/* 4F */  0x004F /*                        LATIN CAPITAL LETTER O */,
/* 50 */  0x0050 /*                        LATIN CAPITAL LETTER P */,
/* 51 */  0x0051 /*                        LATIN CAPITAL LETTER Q */,
/* 52 */  0x0052 /*                        LATIN CAPITAL LETTER R */,
/* 53 */  0x0053 /*                        LATIN CAPITAL LETTER S */,
/* 54 */  0x0054 /*                        LATIN CAPITAL LETTER T */,
/* 55 */  0x0055 /*                        LATIN CAPITAL LETTER U */,
/* 56 */  0x0056 /*                        LATIN CAPITAL LETTER V */,
/* 57 */  0x0057 /*                        LATIN CAPITAL LETTER W */,
/* 58 */  0x0058 /*                        LATIN CAPITAL LETTER X */,
/* 59 */  0x0059 /*                        LATIN CAPITAL LETTER Y */,
/* 5A */  0x005A /*                        LATIN CAPITAL LETTER Z */,
/* 5B */  0x005B /*                           LEFT SQUARE BRACKET */,
/* 5C */  0x005C /*                               REVERSE SOLIDUS */,
/* 5D */  0x005D /*                          RIGHT SQUARE BRACKET */,
/* 5E */  0x005E /*                             CIRCUMFLEX ACCENT */,
/* 5F */  0x005F /*                                      LOW LINE */,
/* 60 */  0x0060 /*                                  GRAVE ACCENT */,
/* 61 */  0x0061 /*                          LATIN SMALL LETTER A */,
/* 62 */  0x0062 /*                          LATIN SMALL LETTER B */,
/* 63 */  0x0063 /*                          LATIN SMALL LETTER C */,
/* 64 */  0x0064 /*                          LATIN SMALL LETTER D */,
/* 65 */  0x0065 /*                          LATIN SMALL LETTER E */,
/* 66 */  0x0066 /*                          LATIN SMALL LETTER F */,
/* 67 */  0x0067 /*                          LATIN SMALL LETTER G */,
/* 68 */  0x0068 /*                          LATIN SMALL LETTER H */,
/* 69 */  0x0069 /*                          LATIN SMALL LETTER I */,
/* 6A */  0x006A /*                          LATIN SMALL LETTER J */,
/* 6B */  0x006B /*                          LATIN SMALL LETTER K */,
/* 6C */  0x006C /*                          LATIN SMALL LETTER L */,
/* 6D */  0x006D /*                          LATIN SMALL LETTER M */,
/* 6E */  0x006E /*                          LATIN SMALL LETTER N */,
/* 6F */  0x006F /*                          LATIN SMALL LETTER O */,
/* 70 */  0x0070 /*                          LATIN SMALL LETTER P */,
/* 71 */  0x0071 /*                          LATIN SMALL LETTER Q */,
/* 72 */  0x0072 /*                          LATIN SMALL LETTER R */,
/* 73 */  0x0073 /*                          LATIN SMALL LETTER S */,
/* 74 */  0x0074 /*                          LATIN SMALL LETTER T */,
/* 75 */  0x0075 /*                          LATIN SMALL LETTER U */,
/* 76 */  0x0076 /*                          LATIN SMALL LETTER V */,
/* 77 */  0x0077 /*                          LATIN SMALL LETTER W */,
/* 78 */  0x0078 /*                          LATIN SMALL LETTER X */,
/* 79 */  0x0079 /*                          LATIN SMALL LETTER Y */,
/* 7A */  0x007A /*                          LATIN SMALL LETTER Z */,
/* 7B */  0x007B /*                            LEFT CURLY BRACKET */,
/* 7C */  0x007C /*                                 VERTICAL LINE */,
/* 7D */  0x007D /*                           RIGHT CURLY BRACKET */,
/* 7E */  0x007E /*                                         TILDE */,
/* 7F */  0x007F /*                                        DELETE */,
/* 80 */  0x0410 /*                     CYRILLIC CAPITAL LETTER A */,
/* 81 */  0x0411 /*                    CYRILLIC CAPITAL LETTER BE */,
/* 82 */  0x0412 /*                    CYRILLIC CAPITAL LETTER VE */,
/* 83 */  0x0413 /*                   CYRILLIC CAPITAL LETTER GHE */,
/* 84 */  0x0414 /*                    CYRILLIC CAPITAL LETTER DE */,
/* 85 */  0x0415 /*                    CYRILLIC CAPITAL LETTER IE */,
/* 86 */  0x0416 /*                   CYRILLIC CAPITAL LETTER ZHE */,
/* 87 */  0x0417 /*                    CYRILLIC CAPITAL LETTER ZE */,
/* 88 */  0x0418 /*                     CYRILLIC CAPITAL LETTER I */,
/* 89 */  0x0419 /*               CYRILLIC CAPITAL LETTER SHORT I */,
/* 8A */  0x041A /*                    CYRILLIC CAPITAL LETTER KA */,
/* 8B */  0x041B /*                    CYRILLIC CAPITAL LETTER EL */,
/* 8C */  0x041C /*                    CYRILLIC CAPITAL LETTER EM */,
/* 8D */  0x041D /*                    CYRILLIC CAPITAL LETTER EN */,
/* 8E */  0x041E /*                     CYRILLIC CAPITAL LETTER O */,
/* 8F */  0x041F /*                    CYRILLIC CAPITAL LETTER PE */,
/* 90 */  0x0420 /*                    CYRILLIC CAPITAL LETTER ER */,
/* 91 */  0x0421 /*                    CYRILLIC CAPITAL LETTER ES */,
/* 92 */  0x0422 /*                    CYRILLIC CAPITAL LETTER TE */,
/* 93 */  0x0423 /*                     CYRILLIC CAPITAL LETTER U */,
/* 94 */  0x0424 /*                    CYRILLIC CAPITAL LETTER EF */,
/* 95 */  0x0425 /*                    CYRILLIC CAPITAL LETTER HA */,
/* 96 */  0x0426 /*                   CYRILLIC CAPITAL LETTER TSE */,
/* 97 */  0x0427 /*                   CYRILLIC CAPITAL LETTER CHE */,
/* 98 */  0x0428 /*                   CYRILLIC CAPITAL LETTER SHA */,
/* 99 */  0x0429 /*                 CYRILLIC CAPITAL LETTER SHCHA */,
/* 9A */  0x042A /*             CYRILLIC CAPITAL LETTER HARD SIGN */,
/* 9B */  0x042B /*                  CYRILLIC CAPITAL LETTER YERU */,
/* 9C */  0x042C /*             CYRILLIC CAPITAL LETTER SOFT SIGN */,
/* 9D */  0x042D /*                     CYRILLIC CAPITAL LETTER E */,
/* 9E */  0x042E /*                    CYRILLIC CAPITAL LETTER YU */,
/* 9F */  0x042F /*                    CYRILLIC CAPITAL LETTER YA */,
/* A0 */  0x0430 /*                       CYRILLIC SMALL LETTER A */,
/* A1 */  0x0431 /*                      CYRILLIC SMALL LETTER BE */,
/* A2 */  0x0432 /*                      CYRILLIC SMALL LETTER VE */,
/* A3 */  0x0433 /*                     CYRILLIC SMALL LETTER GHE */,
/* A4 */  0x0434 /*                      CYRILLIC SMALL LETTER DE */,
/* A5 */  0x0435 /*                      CYRILLIC SMALL LETTER IE */,
/* A6 */  0x0436 /*                     CYRILLIC SMALL LETTER ZHE */,
/* A7 */  0x0437 /*                      CYRILLIC SMALL LETTER ZE */,
/* A8 */  0x0438 /*                       CYRILLIC SMALL LETTER I */,
/* A9 */  0x0439 /*                 CYRILLIC SMALL LETTER SHORT I */,
/* AA */  0x043A /*                      CYRILLIC SMALL LETTER KA */,
/* AB */  0x043B /*                      CYRILLIC SMALL LETTER EL */,
/* AC */  0x043C /*                      CYRILLIC SMALL LETTER EM */,
/* AD */  0x043D /*                      CYRILLIC SMALL LETTER EN */,
/* AE */  0x043E /*                       CYRILLIC SMALL LETTER O */,
/* AF */  0x043F /*                      CYRILLIC SMALL LETTER PE */,
/* B0 */  0x2591 /*                                   LIGHT SHADE */,
/* B1 */  0x2592 /*                                  MEDIUM SHADE */,
/* B2 */  0x2593 /*                                    DARK SHADE */,
/* B3 */  0x2502 /*                   BOX DRAWINGS LIGHT VERTICAL */,
/* B4 */  0x2524 /*          BOX DRAWINGS LIGHT VERTICAL AND LEFT */,
/* B5 */  0x2561 /*  BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE */,
/* B6 */  0x2562 /*  BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE */,
/* B7 */  0x2556 /*      BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE */,
/* B8 */  0x2555 /*      BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE */,
/* B9 */  0x2563 /*         BOX DRAWINGS DOUBLE VERTICAL AND LEFT */,
/* BA */  0x2551 /*                  BOX DRAWINGS DOUBLE VERTICAL */,
/* BB */  0x2557 /*             BOX DRAWINGS DOUBLE DOWN AND LEFT */,
/* BC */  0x255D /*               BOX DRAWINGS DOUBLE UP AND LEFT */,
/* BD */  0x255C /*        BOX DRAWINGS UP DOUBLE AND LEFT SINGLE */,
/* BE */  0x255B /*        BOX DRAWINGS UP SINGLE AND LEFT DOUBLE */,
/* BF */  0x2510 /*              BOX DRAWINGS LIGHT DOWN AND LEFT */,
/* C0 */  0x2514 /*               BOX DRAWINGS LIGHT UP AND RIGHT */,
/* C1 */  0x2534 /*          BOX DRAWINGS LIGHT UP AND HORIZONTAL */,
/* C2 */  0x252C /*        BOX DRAWINGS LIGHT DOWN AND HORIZONTAL */,
/* C3 */  0x251C /*         BOX DRAWINGS LIGHT VERTICAL AND RIGHT */,
/* C4 */  0x2500 /*                 BOX DRAWINGS LIGHT HORIZONTAL */,
/* C5 */  0x253C /*    BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL */,
/* C6 */  0x255E /* BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE */,
/* C7 */  0x255F /* BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE */,
/* C8 */  0x255A /*              BOX DRAWINGS DOUBLE UP AND RIGHT */,
/* C9 */  0x2554 /*            BOX DRAWINGS DOUBLE DOWN AND RIGHT */,
/* CA */  0x2569 /*         BOX DRAWINGS DOUBLE UP AND HORIZONTAL */,
/* CB */  0x2566 /*       BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL */,
/* CC */  0x2560 /*        BOX DRAWINGS DOUBLE VERTICAL AND RIGHT */,
/* CD */  0x2550 /*                BOX DRAWINGS DOUBLE HORIZONTAL */,
/* CE */  0x256C /*   BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL */,
/* CF */  0x2567 /*  BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE */,
/* D0 */  0x2568 /*  BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE */,
/* D1 */  0x2564 /* BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE */,
/* D2 */  0x2565 /* BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE */,
/* D3 */  0x2559 /*       BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE */,
/* D4 */  0x2558 /*       BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE */,
/* D5 */  0x2552 /*     BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE */,
/* D6 */  0x2553 /*     BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE */,
/* D7 */  0x256B /* BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE */,
/* D8 */  0x256A /* BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE */,
/* D9 */  0x2518 /*                BOX DRAWINGS LIGHT UP AND LEFT */,
/* DA */  0x250C /*             BOX DRAWINGS LIGHT DOWN AND RIGHT */,
/* DB */  0x2588 /*                                    FULL BLOCK */,
/* DC */  0x2584 /*                              LOWER HALF BLOCK */,
/* DD */  0x258C /*                               LEFT HALF BLOCK */,
/* DE */  0x2590 /*                              RIGHT HALF BLOCK */,
/* DF */  0x2580 /*                              UPPER HALF BLOCK */,
/* E0 */  0x0440 /*                      CYRILLIC SMALL LETTER ER */,
/* E1 */  0x0441 /*                      CYRILLIC SMALL LETTER ES */,
/* E2 */  0x0442 /*                      CYRILLIC SMALL LETTER TE */,
/* E3 */  0x0443 /*                       CYRILLIC SMALL LETTER U */,
/* E4 */  0x0444 /*                      CYRILLIC SMALL LETTER EF */,
/* E5 */  0x0445 /*                      CYRILLIC SMALL LETTER HA */,
/* E6 */  0x0446 /*                     CYRILLIC SMALL LETTER TSE */,
/* E7 */  0x0447 /*                     CYRILLIC SMALL LETTER CHE */,
/* E8 */  0x0448 /*                     CYRILLIC SMALL LETTER SHA */,
/* E9 */  0x0449 /*                   CYRILLIC SMALL LETTER SHCHA */,
/* EA */  0x044A /*               CYRILLIC SMALL LETTER HARD SIGN */,
/* EB */  0x044B /*                    CYRILLIC SMALL LETTER YERU */,
/* EC */  0x044C /*               CYRILLIC SMALL LETTER SOFT SIGN */,
/* ED */  0x044D /*                       CYRILLIC SMALL LETTER E */,
/* EE */  0x044E /*                      CYRILLIC SMALL LETTER YU */,
/* EF */  0x044F /*                      CYRILLIC SMALL LETTER YA */,
/* F0 */  0x0401 /*                    CYRILLIC CAPITAL LETTER IO */,
/* F1 */  0x0451 /*                      CYRILLIC SMALL LETTER IO */,
/* F2 */  0x0404 /*          CYRILLIC CAPITAL LETTER UKRAINIAN IE */,
/* F3 */  0x0454 /*            CYRILLIC SMALL LETTER UKRAINIAN IE */,
/* F4 */  0x0407 /*                    CYRILLIC CAPITAL LETTER YI */,
/* F5 */  0x0457 /*                      CYRILLIC SMALL LETTER YI */,
/* F6 */  0x040E /*               CYRILLIC CAPITAL LETTER SHORT U */,
/* F7 */  0x045E /*                 CYRILLIC SMALL LETTER SHORT U */,
/* F8 */  0x00B0 /*                                   DEGREE SIGN */,
/* F9 */  0x2219 /*                               BULLET OPERATOR */,
/* FA */  0x00B7 /*                                    MIDDLE DOT */,
/* FB */  0x221A /*                                   SQUARE ROOT */,
/* FC */  0x2116 /*                                   NUMERO SIGN */,
/* FD */  0x00A4 /*                                 CURRENCY SIGN */,
/* FE */  0x25A0 /*                                  BLACK SQUARE */,
/* FF */  0x00A0 /*                                NO-BREAK SPACE */,
};


static const int CANT_MAP_CHARACTER = 0;

static const UCHAR from_unicode_mapping_array[] = {
/* U+XX00 */	CANT_MAP_CHARACTER,	/* 0 */
/* U+XX01 */	CANT_MAP_CHARACTER,	/* 1 */
/* U+XX02 */	CANT_MAP_CHARACTER,	/* 2 */
/* U+XX03 */	CANT_MAP_CHARACTER,	/* 3 */
/* U+XX04 */	CANT_MAP_CHARACTER,	/* 4 */
/* U+XX05 */	CANT_MAP_CHARACTER,	/* 5 */
/* U+XX06 */	CANT_MAP_CHARACTER,	/* 6 */
/* U+XX07 */	CANT_MAP_CHARACTER,	/* 7 */
/* U+XX08 */	CANT_MAP_CHARACTER,	/* 8 */
/* U+XX09 */	CANT_MAP_CHARACTER,	/* 9 */
/* U+XX0A */	CANT_MAP_CHARACTER,	/* 10 */
/* U+XX0B */	CANT_MAP_CHARACTER,	/* 11 */
/* U+XX0C */	CANT_MAP_CHARACTER,	/* 12 */
/* U+XX0D */	CANT_MAP_CHARACTER,	/* 13 */
/* U+XX0E */	CANT_MAP_CHARACTER,	/* 14 */
/* U+XX0F */	CANT_MAP_CHARACTER,	/* 15 */
/* U+XX10 */	CANT_MAP_CHARACTER,	/* 16 */
/* U+XX11 */	CANT_MAP_CHARACTER,	/* 17 */
/* U+XX12 */	CANT_MAP_CHARACTER,	/* 18 */
/* U+XX13 */	CANT_MAP_CHARACTER,	/* 19 */
/* U+XX14 */	CANT_MAP_CHARACTER,	/* 20 */
/* U+XX15 */	CANT_MAP_CHARACTER,	/* 21 */
/* U+XX16 */	CANT_MAP_CHARACTER,	/* 22 */
/* U+XX17 */	CANT_MAP_CHARACTER,	/* 23 */
/* U+XX18 */	CANT_MAP_CHARACTER,	/* 24 */
/* U+XX19 */	CANT_MAP_CHARACTER,	/* 25 */
/* U+XX1A */	CANT_MAP_CHARACTER,	/* 26 */
/* U+XX1B */	CANT_MAP_CHARACTER,	/* 27 */
/* U+XX1C */	CANT_MAP_CHARACTER,	/* 28 */
/* U+XX1D */	CANT_MAP_CHARACTER,	/* 29 */
/* U+XX1E */	CANT_MAP_CHARACTER,	/* 30 */
/* U+XX1F */	CANT_MAP_CHARACTER,	/* 31 */
/* U+XX20 */	CANT_MAP_CHARACTER,	/* 32 */
/* U+XX21 */	CANT_MAP_CHARACTER,	/* 33 */
/* U+XX22 */	CANT_MAP_CHARACTER,	/* 34 */
/* U+XX23 */	CANT_MAP_CHARACTER,	/* 35 */
/* U+XX24 */	CANT_MAP_CHARACTER,	/* 36 */
/* U+XX25 */	CANT_MAP_CHARACTER,	/* 37 */
/* U+XX26 */	CANT_MAP_CHARACTER,	/* 38 */
/* U+XX27 */	CANT_MAP_CHARACTER,	/* 39 */
/* U+XX28 */	CANT_MAP_CHARACTER,	/* 40 */
/* U+XX29 */	CANT_MAP_CHARACTER,	/* 41 */
/* U+XX2A */	CANT_MAP_CHARACTER,	/* 42 */
/* U+XX2B */	CANT_MAP_CHARACTER,	/* 43 */
/* U+XX2C */	CANT_MAP_CHARACTER,	/* 44 */
/* U+XX2D */	CANT_MAP_CHARACTER,	/* 45 */
/* U+XX2E */	CANT_MAP_CHARACTER,	/* 46 */
/* U+XX2F */	CANT_MAP_CHARACTER,	/* 47 */
/* U+XX30 */	CANT_MAP_CHARACTER,	/* 48 */
/* U+XX31 */	CANT_MAP_CHARACTER,	/* 49 */
/* U+XX32 */	CANT_MAP_CHARACTER,	/* 50 */
/* U+XX33 */	CANT_MAP_CHARACTER,	/* 51 */
/* U+XX34 */	CANT_MAP_CHARACTER,	/* 52 */
/* U+XX35 */	CANT_MAP_CHARACTER,	/* 53 */
/* U+XX36 */	CANT_MAP_CHARACTER,	/* 54 */
/* U+XX37 */	CANT_MAP_CHARACTER,	/* 55 */
/* U+XX38 */	CANT_MAP_CHARACTER,	/* 56 */
/* U+XX39 */	CANT_MAP_CHARACTER,	/* 57 */
/* U+XX3A */	CANT_MAP_CHARACTER,	/* 58 */
/* U+XX3B */	CANT_MAP_CHARACTER,	/* 59 */
/* U+XX3C */	CANT_MAP_CHARACTER,	/* 60 */
/* U+XX3D */	CANT_MAP_CHARACTER,	/* 61 */
/* U+XX3E */	CANT_MAP_CHARACTER,	/* 62 */
/* U+XX3F */	CANT_MAP_CHARACTER,	/* 63 */
/* U+XX40 */	CANT_MAP_CHARACTER,	/* 64 */
/* U+XX41 */	CANT_MAP_CHARACTER,	/* 65 */
/* U+XX42 */	CANT_MAP_CHARACTER,	/* 66 */
/* U+XX43 */	CANT_MAP_CHARACTER,	/* 67 */
/* U+XX44 */	CANT_MAP_CHARACTER,	/* 68 */
/* U+XX45 */	CANT_MAP_CHARACTER,	/* 69 */
/* U+XX46 */	CANT_MAP_CHARACTER,	/* 70 */
/* U+XX47 */	CANT_MAP_CHARACTER,	/* 71 */
/* U+XX48 */	CANT_MAP_CHARACTER,	/* 72 */
/* U+XX49 */	CANT_MAP_CHARACTER,	/* 73 */
/* U+XX4A */	CANT_MAP_CHARACTER,	/* 74 */
/* U+XX4B */	CANT_MAP_CHARACTER,	/* 75 */
/* U+XX4C */	CANT_MAP_CHARACTER,	/* 76 */
/* U+XX4D */	CANT_MAP_CHARACTER,	/* 77 */
/* U+XX4E */	CANT_MAP_CHARACTER,	/* 78 */
/* U+XX4F */	CANT_MAP_CHARACTER,	/* 79 */
/* U+XX50 */	CANT_MAP_CHARACTER,	/* 80 */
/* U+XX51 */	CANT_MAP_CHARACTER,	/* 81 */
/* U+XX52 */	CANT_MAP_CHARACTER,	/* 82 */
/* U+XX53 */	CANT_MAP_CHARACTER,	/* 83 */
/* U+XX54 */	CANT_MAP_CHARACTER,	/* 84 */
/* U+XX55 */	CANT_MAP_CHARACTER,	/* 85 */
/* U+XX56 */	CANT_MAP_CHARACTER,	/* 86 */
/* U+XX57 */	CANT_MAP_CHARACTER,	/* 87 */
/* U+XX58 */	CANT_MAP_CHARACTER,	/* 88 */
/* U+XX59 */	CANT_MAP_CHARACTER,	/* 89 */
/* U+XX5A */	CANT_MAP_CHARACTER,	/* 90 */
/* U+XX5B */	CANT_MAP_CHARACTER,	/* 91 */
/* U+XX5C */	CANT_MAP_CHARACTER,	/* 92 */
/* U+XX5D */	CANT_MAP_CHARACTER,	/* 93 */
/* U+XX5E */	CANT_MAP_CHARACTER,	/* 94 */
/* U+XX5F */	CANT_MAP_CHARACTER,	/* 95 */
/* U+XX60 */	CANT_MAP_CHARACTER,	/* 96 */
/* U+XX61 */	CANT_MAP_CHARACTER,	/* 97 */
/* U+XX62 */	CANT_MAP_CHARACTER,	/* 98 */
/* U+XX63 */	CANT_MAP_CHARACTER,	/* 99 */
/* U+XX64 */	CANT_MAP_CHARACTER,	/* 100 */
/* U+XX65 */	CANT_MAP_CHARACTER,	/* 101 */
/* U+XX66 */	CANT_MAP_CHARACTER,	/* 102 */
/* U+XX67 */	CANT_MAP_CHARACTER,	/* 103 */
/* U+XX68 */	CANT_MAP_CHARACTER,	/* 104 */
/* U+XX69 */	CANT_MAP_CHARACTER,	/* 105 */
/* U+XX6A */	CANT_MAP_CHARACTER,	/* 106 */
/* U+XX6B */	CANT_MAP_CHARACTER,	/* 107 */
/* U+XX6C */	CANT_MAP_CHARACTER,	/* 108 */
/* U+XX6D */	CANT_MAP_CHARACTER,	/* 109 */
/* U+XX6E */	CANT_MAP_CHARACTER,	/* 110 */
/* U+XX6F */	CANT_MAP_CHARACTER,	/* 111 */
/* U+XX70 */	CANT_MAP_CHARACTER,	/* 112 */
/* U+XX71 */	CANT_MAP_CHARACTER,	/* 113 */
/* U+XX72 */	CANT_MAP_CHARACTER,	/* 114 */
/* U+XX73 */	CANT_MAP_CHARACTER,	/* 115 */
/* U+XX74 */	CANT_MAP_CHARACTER,	/* 116 */
/* U+XX75 */	CANT_MAP_CHARACTER,	/* 117 */
/* U+XX76 */	CANT_MAP_CHARACTER,	/* 118 */
/* U+XX77 */	CANT_MAP_CHARACTER,	/* 119 */
/* U+XX78 */	CANT_MAP_CHARACTER,	/* 120 */
/* U+XX79 */	CANT_MAP_CHARACTER,	/* 121 */
/* U+XX7A */	CANT_MAP_CHARACTER,	/* 122 */
/* U+XX7B */	CANT_MAP_CHARACTER,	/* 123 */
/* U+XX7C */	CANT_MAP_CHARACTER,	/* 124 */
/* U+XX7D */	CANT_MAP_CHARACTER,	/* 125 */
/* U+XX7E */	CANT_MAP_CHARACTER,	/* 126 */
/* U+XX7F */	CANT_MAP_CHARACTER,	/* 127 */
/* U+XX80 */	CANT_MAP_CHARACTER,	/* 128 */
/* U+XX81 */	CANT_MAP_CHARACTER,	/* 129 */
/* U+XX82 */	CANT_MAP_CHARACTER,	/* 130 */
/* U+XX83 */	CANT_MAP_CHARACTER,	/* 131 */
/* U+XX84 */	CANT_MAP_CHARACTER,	/* 132 */
/* U+XX85 */	CANT_MAP_CHARACTER,	/* 133 */
/* U+XX86 */	CANT_MAP_CHARACTER,	/* 134 */
/* U+XX87 */	CANT_MAP_CHARACTER,	/* 135 */
/* U+XX88 */	CANT_MAP_CHARACTER,	/* 136 */
/* U+XX89 */	CANT_MAP_CHARACTER,	/* 137 */
/* U+XX8A */	CANT_MAP_CHARACTER,	/* 138 */
/* U+XX8B */	CANT_MAP_CHARACTER,	/* 139 */
/* U+XX8C */	CANT_MAP_CHARACTER,	/* 140 */
/* U+XX8D */	CANT_MAP_CHARACTER,	/* 141 */
/* U+XX8E */	CANT_MAP_CHARACTER,	/* 142 */
/* U+XX8F */	CANT_MAP_CHARACTER,	/* 143 */
/* U+XX90 */	CANT_MAP_CHARACTER,	/* 144 */
/* U+XX91 */	CANT_MAP_CHARACTER,	/* 145 */
/* U+XX92 */	CANT_MAP_CHARACTER,	/* 146 */
/* U+XX93 */	CANT_MAP_CHARACTER,	/* 147 */
/* U+XX94 */	CANT_MAP_CHARACTER,	/* 148 */
/* U+XX95 */	CANT_MAP_CHARACTER,	/* 149 */
/* U+XX96 */	CANT_MAP_CHARACTER,	/* 150 */
/* U+XX97 */	CANT_MAP_CHARACTER,	/* 151 */
/* U+XX98 */	CANT_MAP_CHARACTER,	/* 152 */
/* U+XX99 */	CANT_MAP_CHARACTER,	/* 153 */
/* U+XX9A */	CANT_MAP_CHARACTER,	/* 154 */
/* U+XX9B */	CANT_MAP_CHARACTER,	/* 155 */
/* U+XX9C */	CANT_MAP_CHARACTER,	/* 156 */
/* U+XX9D */	CANT_MAP_CHARACTER,	/* 157 */
/* U+XX9E */	CANT_MAP_CHARACTER,	/* 158 */
/* U+XX9F */	CANT_MAP_CHARACTER,	/* 159 */
/* U+XXA0 */	CANT_MAP_CHARACTER,	/* 160 */
/* U+XXA1 */	CANT_MAP_CHARACTER,	/* 161 */
/* U+XXA2 */	CANT_MAP_CHARACTER,	/* 162 */
/* U+XXA3 */	CANT_MAP_CHARACTER,	/* 163 */
/* U+XXA4 */	CANT_MAP_CHARACTER,	/* 164 */
/* U+XXA5 */	CANT_MAP_CHARACTER,	/* 165 */
/* U+XXA6 */	CANT_MAP_CHARACTER,	/* 166 */
/* U+XXA7 */	CANT_MAP_CHARACTER,	/* 167 */
/* U+XXA8 */	CANT_MAP_CHARACTER,	/* 168 */
/* U+XXA9 */	CANT_MAP_CHARACTER,	/* 169 */
/* U+XXAA */	CANT_MAP_CHARACTER,	/* 170 */
/* U+XXAB */	CANT_MAP_CHARACTER,	/* 171 */
/* U+XXAC */	CANT_MAP_CHARACTER,	/* 172 */
/* U+XXAD */	CANT_MAP_CHARACTER,	/* 173 */
/* U+XXAE */	CANT_MAP_CHARACTER,	/* 174 */
/* U+XXAF */	CANT_MAP_CHARACTER,	/* 175 */
/* U+XXB0 */	CANT_MAP_CHARACTER,	/* 176 */
/* U+XXB1 */	CANT_MAP_CHARACTER,	/* 177 */
/* U+XXB2 */	CANT_MAP_CHARACTER,	/* 178 */
/* U+XXB3 */	CANT_MAP_CHARACTER,	/* 179 */
/* U+XXB4 */	CANT_MAP_CHARACTER,	/* 180 */
/* U+XXB5 */	CANT_MAP_CHARACTER,	/* 181 */
/* U+XXB6 */	CANT_MAP_CHARACTER,	/* 182 */
/* U+XXB7 */	CANT_MAP_CHARACTER,	/* 183 */
/* U+XXB8 */	CANT_MAP_CHARACTER,	/* 184 */
/* U+XXB9 */	CANT_MAP_CHARACTER,	/* 185 */
/* U+XXBA */	CANT_MAP_CHARACTER,	/* 186 */
/* U+XXBB */	CANT_MAP_CHARACTER,	/* 187 */
/* U+XXBC */	CANT_MAP_CHARACTER,	/* 188 */
/* U+XXBD */	CANT_MAP_CHARACTER,	/* 189 */
/* U+XXBE */	CANT_MAP_CHARACTER,	/* 190 */
/* U+XXBF */	CANT_MAP_CHARACTER,	/* 191 */
/* U+XXC0 */	CANT_MAP_CHARACTER,	/* 192 */
/* U+XXC1 */	CANT_MAP_CHARACTER,	/* 193 */
/* U+XXC2 */	CANT_MAP_CHARACTER,	/* 194 */
/* U+XXC3 */	CANT_MAP_CHARACTER,	/* 195 */
/* U+XXC4 */	CANT_MAP_CHARACTER,	/* 196 */
/* U+XXC5 */	CANT_MAP_CHARACTER,	/* 197 */
/* U+XXC6 */	CANT_MAP_CHARACTER,	/* 198 */
/* U+XXC7 */	CANT_MAP_CHARACTER,	/* 199 */
/* U+XXC8 */	CANT_MAP_CHARACTER,	/* 200 */
/* U+XXC9 */	CANT_MAP_CHARACTER,	/* 201 */
/* U+XXCA */	CANT_MAP_CHARACTER,	/* 202 */
/* U+XXCB */	CANT_MAP_CHARACTER,	/* 203 */
/* U+XXCC */	CANT_MAP_CHARACTER,	/* 204 */
/* U+XXCD */	CANT_MAP_CHARACTER,	/* 205 */
/* U+XXCE */	CANT_MAP_CHARACTER,	/* 206 */
/* U+XXCF */	CANT_MAP_CHARACTER,	/* 207 */
/* U+XXD0 */	CANT_MAP_CHARACTER,	/* 208 */
/* U+XXD1 */	CANT_MAP_CHARACTER,	/* 209 */
/* U+XXD2 */	CANT_MAP_CHARACTER,	/* 210 */
/* U+XXD3 */	CANT_MAP_CHARACTER,	/* 211 */
/* U+XXD4 */	CANT_MAP_CHARACTER,	/* 212 */
/* U+XXD5 */	CANT_MAP_CHARACTER,	/* 213 */
/* U+XXD6 */	CANT_MAP_CHARACTER,	/* 214 */
/* U+XXD7 */	CANT_MAP_CHARACTER,	/* 215 */
/* U+XXD8 */	CANT_MAP_CHARACTER,	/* 216 */
/* U+XXD9 */	CANT_MAP_CHARACTER,	/* 217 */
/* U+XXDA */	CANT_MAP_CHARACTER,	/* 218 */
/* U+XXDB */	CANT_MAP_CHARACTER,	/* 219 */
/* U+XXDC */	CANT_MAP_CHARACTER,	/* 220 */
/* U+XXDD */	CANT_MAP_CHARACTER,	/* 221 */
/* U+XXDE */	CANT_MAP_CHARACTER,	/* 222 */
/* U+XXDF */	CANT_MAP_CHARACTER,	/* 223 */
/* U+XXE0 */	CANT_MAP_CHARACTER,	/* 224 */
/* U+XXE1 */	CANT_MAP_CHARACTER,	/* 225 */
/* U+XXE2 */	CANT_MAP_CHARACTER,	/* 226 */
/* U+XXE3 */	CANT_MAP_CHARACTER,	/* 227 */
/* U+XXE4 */	CANT_MAP_CHARACTER,	/* 228 */
/* U+XXE5 */	CANT_MAP_CHARACTER,	/* 229 */
/* U+XXE6 */	CANT_MAP_CHARACTER,	/* 230 */
/* U+XXE7 */	CANT_MAP_CHARACTER,	/* 231 */
/* U+XXE8 */	CANT_MAP_CHARACTER,	/* 232 */
/* U+XXE9 */	CANT_MAP_CHARACTER,	/* 233 */
/* U+XXEA */	CANT_MAP_CHARACTER,	/* 234 */
/* U+XXEB */	CANT_MAP_CHARACTER,	/* 235 */
/* U+XXEC */	CANT_MAP_CHARACTER,	/* 236 */
/* U+XXED */	CANT_MAP_CHARACTER,	/* 237 */
/* U+XXEE */	CANT_MAP_CHARACTER,	/* 238 */
/* U+XXEF */	CANT_MAP_CHARACTER,	/* 239 */
/* U+XXF0 */	CANT_MAP_CHARACTER,	/* 240 */
/* U+XXF1 */	CANT_MAP_CHARACTER,	/* 241 */
/* U+XXF2 */	CANT_MAP_CHARACTER,	/* 242 */
/* U+XXF3 */	CANT_MAP_CHARACTER,	/* 243 */
/* U+XXF4 */	CANT_MAP_CHARACTER,	/* 244 */
/* U+XXF5 */	CANT_MAP_CHARACTER,	/* 245 */
/* U+XXF6 */	CANT_MAP_CHARACTER,	/* 246 */
/* U+XXF7 */	CANT_MAP_CHARACTER,	/* 247 */
/* U+XXF8 */	CANT_MAP_CHARACTER,	/* 248 */
/* U+XXF9 */	CANT_MAP_CHARACTER,	/* 249 */
/* U+XXFA */	CANT_MAP_CHARACTER,	/* 250 */
/* U+XXFB */	CANT_MAP_CHARACTER,	/* 251 */
/* U+XXFC */	CANT_MAP_CHARACTER,	/* 252 */
/* U+XXFD */	CANT_MAP_CHARACTER,	/* 253 */
/* U+XXFE */	CANT_MAP_CHARACTER,	/* 254 */
/* U+XXFF */	CANT_MAP_CHARACTER,	/* 255 */
/* U+0000 */	0x00	/*                                          NULL */,/* 256 */
/* U+0001 */	0x01	/*                              START OF HEADING */,/* 257 */
/* U+0002 */	0x02	/*                                 START OF TEXT */,/* 258 */
/* U+0003 */	0x03	/*                                   END OF TEXT */,/* 259 */
/* U+0004 */	0x04	/*                           END OF TRANSMISSION */,/* 260 */
/* U+0005 */	0x05	/*                                       ENQUIRY */,/* 261 */
/* U+0006 */	0x06	/*                                   ACKNOWLEDGE */,/* 262 */
/* U+0007 */	0x07	/*                                          BELL */,/* 263 */
/* U+0008 */	0x08	/*                                     BACKSPACE */,/* 264 */
/* U+0009 */	0x09	/*                          CHARACTER TABULATION */,/* 265 */
/* U+000A */	0x0A	/*                                LINE FEED (LF) */,/* 266 */
/* U+000B */	0x0B	/*                               LINE TABULATION */,/* 267 */
/* U+000C */	0x0C	/*                                FORM FEED (FF) */,/* 268 */
/* U+000D */	0x0D	/*                          CARRIAGE RETURN (CR) */,/* 269 */
/* U+000E */	0x0E	/*                                     SHIFT OUT */,/* 270 */
/* U+000F */	0x0F	/*                                      SHIFT IN */,/* 271 */
/* U+0010 */	0x10	/*                              DATA LINK ESCAPE */,/* 272 */
/* U+0011 */	0x11	/*                            DEVICE CONTROL ONE */,/* 273 */
/* U+0012 */	0x12	/*                            DEVICE CONTROL TWO */,/* 274 */
/* U+0013 */	0x13	/*                          DEVICE CONTROL THREE */,/* 275 */
/* U+0014 */	0x14	/*                           DEVICE CONTROL FOUR */,/* 276 */
/* U+0015 */	0x15	/*                          NEGATIVE ACKNOWLEDGE */,/* 277 */
/* U+0016 */	0x16	/*                              SYNCHRONOUS IDLE */,/* 278 */
/* U+0017 */	0x17	/*                     END OF TRANSMISSION BLOCK */,/* 279 */
/* U+0018 */	0x18	/*                                        CANCEL */,/* 280 */
/* U+0019 */	0x19	/*                                 END OF MEDIUM */,/* 281 */
/* U+001A */	0x1A	/*                                    SUBSTITUTE */,/* 282 */
/* U+001B */	0x1B	/*                                        ESCAPE */,/* 283 */
/* U+001C */	0x1C	/*                    INFORMATION SEPARATOR FOUR */,/* 284 */
/* U+001D */	0x1D	/*                   INFORMATION SEPARATOR THREE */,/* 285 */
/* U+001E */	0x1E	/*                     INFORMATION SEPARATOR TWO */,/* 286 */
/* U+001F */	0x1F	/*                     INFORMATION SEPARATOR ONE */,/* 287 */
/* U+0020 */	0x20	/*                                         SPACE */,/* 288 */
/* U+0021 */	0x21	/*                              EXCLAMATION MARK */,/* 289 */
/* U+0022 */	0x22	/*                                QUOTATION MARK */,/* 290 */
/* U+0023 */	0x23	/*                                   NUMBER SIGN */,/* 291 */
/* U+0024 */	0x24	/*                                   DOLLAR SIGN */,/* 292 */
/* U+0025 */	0x25	/*                                  PERCENT SIGN */,/* 293 */
/* U+0026 */	0x26	/*                                     AMPERSAND */,/* 294 */
/* U+0027 */	0x27	/*                                    APOSTROPHE */,/* 295 */
/* U+0028 */	0x28	/*                              LEFT PARENTHESIS */,/* 296 */
/* U+0029 */	0x29	/*                             RIGHT PARENTHESIS */,/* 297 */
/* U+002A */	0x2A	/*                                      ASTERISK */,/* 298 */
/* U+002B */	0x2B	/*                                     PLUS SIGN */,/* 299 */
/* U+002C */	0x2C	/*                                         COMMA */,/* 300 */
/* U+002D */	0x2D	/*                                  HYPHEN-MINUS */,/* 301 */
/* U+002E */	0x2E	/*                                     FULL STOP */,/* 302 */
/* U+002F */	0x2F	/*                                       SOLIDUS */,/* 303 */
/* U+0030 */	0x30	/*                                    DIGIT ZERO */,/* 304 */
/* U+0031 */	0x31	/*                                     DIGIT ONE */,/* 305 */
/* U+0032 */	0x32	/*                                     DIGIT TWO */,/* 306 */
/* U+0033 */	0x33	/*                                   DIGIT THREE */,/* 307 */
/* U+0034 */	0x34	/*                                    DIGIT FOUR */,/* 308 */
/* U+0035 */	0x35	/*                                    DIGIT FIVE */,/* 309 */
/* U+0036 */	0x36	/*                                     DIGIT SIX */,/* 310 */
/* U+0037 */	0x37	/*                                   DIGIT SEVEN */,/* 311 */
/* U+0038 */	0x38	/*                                   DIGIT EIGHT */,/* 312 */
/* U+0039 */	0x39	/*                                    DIGIT NINE */,/* 313 */
/* U+003A */	0x3A	/*                                         COLON */,/* 314 */
/* U+003B */	0x3B	/*                                     SEMICOLON */,/* 315 */
/* U+003C */	0x3C	/*                                LESS-THAN SIGN */,/* 316 */
/* U+003D */	0x3D	/*                                   EQUALS SIGN */,/* 317 */
/* U+003E */	0x3E	/*                             GREATER-THAN SIGN */,/* 318 */
/* U+003F */	0x3F	/*                                 QUESTION MARK */,/* 319 */
/* U+0040 */	0x40	/*                                 COMMERCIAL AT */,/* 320 */
/* U+0041 */	0x41	/*                        LATIN CAPITAL LETTER A */,/* 321 */
/* U+0042 */	0x42	/*                        LATIN CAPITAL LETTER B */,/* 322 */
/* U+0043 */	0x43	/*                        LATIN CAPITAL LETTER C */,/* 323 */
/* U+0044 */	0x44	/*                        LATIN CAPITAL LETTER D */,/* 324 */
/* U+0045 */	0x45	/*                        LATIN CAPITAL LETTER E */,/* 325 */
/* U+0046 */	0x46	/*                        LATIN CAPITAL LETTER F */,/* 326 */
/* U+0047 */	0x47	/*                        LATIN CAPITAL LETTER G */,/* 327 */
/* U+0048 */	0x48	/*                        LATIN CAPITAL LETTER H */,/* 328 */
/* U+0049 */	0x49	/*                        LATIN CAPITAL LETTER I */,/* 329 */
/* U+004A */	0x4A	/*                        LATIN CAPITAL LETTER J */,/* 330 */
/* U+004B */	0x4B	/*                        LATIN CAPITAL LETTER K */,/* 331 */
/* U+004C */	0x4C	/*                        LATIN CAPITAL LETTER L */,/* 332 */
/* U+004D */	0x4D	/*                        LATIN CAPITAL LETTER M */,/* 333 */
/* U+004E */	0x4E	/*                        LATIN CAPITAL LETTER N */,/* 334 */
/* U+004F */	0x4F	/*                        LATIN CAPITAL LETTER O */,/* 335 */
/* U+0050 */	0x50	/*                        LATIN CAPITAL LETTER P */,/* 336 */
/* U+0051 */	0x51	/*                        LATIN CAPITAL LETTER Q */,/* 337 */
/* U+0052 */	0x52	/*                        LATIN CAPITAL LETTER R */,/* 338 */
/* U+0053 */	0x53	/*                        LATIN CAPITAL LETTER S */,/* 339 */
/* U+0054 */	0x54	/*                        LATIN CAPITAL LETTER T */,/* 340 */
/* U+0055 */	0x55	/*                        LATIN CAPITAL LETTER U */,/* 341 */
/* U+0056 */	0x56	/*                        LATIN CAPITAL LETTER V */,/* 342 */
/* U+0057 */	0x57	/*                        LATIN CAPITAL LETTER W */,/* 343 */
/* U+0058 */	0x58	/*                        LATIN CAPITAL LETTER X */,/* 344 */
/* U+0059 */	0x59	/*                        LATIN CAPITAL LETTER Y */,/* 345 */
/* U+005A */	0x5A	/*                        LATIN CAPITAL LETTER Z */,/* 346 */
/* U+005B */	0x5B	/*                           LEFT SQUARE BRACKET */,/* 347 */
/* U+005C */	0x5C	/*                               REVERSE SOLIDUS */,/* 348 */
/* U+005D */	0x5D	/*                          RIGHT SQUARE BRACKET */,/* 349 */
/* U+005E */	0x5E	/*                             CIRCUMFLEX ACCENT */,/* 350 */
/* U+005F */	0x5F	/*                                      LOW LINE */,/* 351 */
/* U+0060 */	0x60	/*                                  GRAVE ACCENT */,/* 352 */
/* U+0061 */	0x61	/*                          LATIN SMALL LETTER A */,/* 353 */
/* U+0062 */	0x62	/*                          LATIN SMALL LETTER B */,/* 354 */
/* U+0063 */	0x63	/*                          LATIN SMALL LETTER C */,/* 355 */
/* U+0064 */	0x64	/*                          LATIN SMALL LETTER D */,/* 356 */
/* U+0065 */	0x65	/*                          LATIN SMALL LETTER E */,/* 357 */
/* U+0066 */	0x66	/*                          LATIN SMALL LETTER F */,/* 358 */
/* U+0067 */	0x67	/*                          LATIN SMALL LETTER G */,/* 359 */
/* U+0068 */	0x68	/*                          LATIN SMALL LETTER H */,/* 360 */
/* U+0069 */	0x69	/*                          LATIN SMALL LETTER I */,/* 361 */
/* U+006A */	0x6A	/*                          LATIN SMALL LETTER J */,/* 362 */
/* U+006B */	0x6B	/*                          LATIN SMALL LETTER K */,/* 363 */
/* U+006C */	0x6C	/*                          LATIN SMALL LETTER L */,/* 364 */
/* U+006D */	0x6D	/*                          LATIN SMALL LETTER M */,/* 365 */
/* U+006E */	0x6E	/*                          LATIN SMALL LETTER N */,/* 366 */
/* U+006F */	0x6F	/*                          LATIN SMALL LETTER O */,/* 367 */
/* U+0070 */	0x70	/*                          LATIN SMALL LETTER P */,/* 368 */
/* U+0071 */	0x71	/*                          LATIN SMALL LETTER Q */,/* 369 */
/* U+0072 */	0x72	/*                          LATIN SMALL LETTER R */,/* 370 */
/* U+0073 */	0x73	/*                          LATIN SMALL LETTER S */,/* 371 */
/* U+0074 */	0x74	/*                          LATIN SMALL LETTER T */,/* 372 */
/* U+0075 */	0x75	/*                          LATIN SMALL LETTER U */,/* 373 */
/* U+0076 */	0x76	/*                          LATIN SMALL LETTER V */,/* 374 */
/* U+0077 */	0x77	/*                          LATIN SMALL LETTER W */,/* 375 */
/* U+0078 */	0x78	/*                          LATIN SMALL LETTER X */,/* 376 */
/* U+0079 */	0x79	/*                          LATIN SMALL LETTER Y */,/* 377 */
/* U+007A */	0x7A	/*                          LATIN SMALL LETTER Z */,/* 378 */
/* U+007B */	0x7B	/*                            LEFT CURLY BRACKET */,/* 379 */
/* U+007C */	0x7C	/*                                 VERTICAL LINE */,/* 380 */
/* U+007D */	0x7D	/*                           RIGHT CURLY BRACKET */,/* 381 */
/* U+007E */	0x7E	/*                                         TILDE */,/* 382 */
/* U+007F */	0x7F	/*                                        DELETE */,/* 383 */
/* U+0080 */	CANT_MAP_CHARACTER,	/* 384 */
/* U+0081 */	CANT_MAP_CHARACTER,	/* 385 */
/* U+0082 */	CANT_MAP_CHARACTER,	/* 386 */
/* U+0083 */	CANT_MAP_CHARACTER,	/* 387 */
/* U+0084 */	CANT_MAP_CHARACTER,	/* 388 */
/* U+0085 */	CANT_MAP_CHARACTER,	/* 389 */
/* U+0086 */	CANT_MAP_CHARACTER,	/* 390 */
/* U+0087 */	CANT_MAP_CHARACTER,	/* 391 */
/* U+0088 */	CANT_MAP_CHARACTER,	/* 392 */
/* U+0089 */	CANT_MAP_CHARACTER,	/* 393 */
/* U+008A */	CANT_MAP_CHARACTER,	/* 394 */
/* U+008B */	CANT_MAP_CHARACTER,	/* 395 */
/* U+008C */	CANT_MAP_CHARACTER,	/* 396 */
/* U+008D */	CANT_MAP_CHARACTER,	/* 397 */
/* U+008E */	CANT_MAP_CHARACTER,	/* 398 */
/* U+008F */	CANT_MAP_CHARACTER,	/* 399 */
/* U+0090 */	CANT_MAP_CHARACTER,	/* 400 */
/* U+0091 */	CANT_MAP_CHARACTER,	/* 401 */
/* U+0092 */	CANT_MAP_CHARACTER,	/* 402 */
/* U+0093 */	CANT_MAP_CHARACTER,	/* 403 */
/* U+0094 */	CANT_MAP_CHARACTER,	/* 404 */
/* U+0095 */	CANT_MAP_CHARACTER,	/* 405 */
/* U+0096 */	CANT_MAP_CHARACTER,	/* 406 */
/* U+0097 */	CANT_MAP_CHARACTER,	/* 407 */
/* U+0098 */	CANT_MAP_CHARACTER,	/* 408 */
/* U+0099 */	CANT_MAP_CHARACTER,	/* 409 */
/* U+009A */	CANT_MAP_CHARACTER,	/* 410 */
/* U+009B */	CANT_MAP_CHARACTER,	/* 411 */
/* U+009C */	CANT_MAP_CHARACTER,	/* 412 */
/* U+009D */	CANT_MAP_CHARACTER,	/* 413 */
/* U+009E */	CANT_MAP_CHARACTER,	/* 414 */
/* U+009F */	CANT_MAP_CHARACTER,	/* 415 */
/* U+00A0 */	0xFF	/*                                NO-BREAK SPACE */,/* 416 */
/* U+00A1 */	CANT_MAP_CHARACTER,	/* 417 */
/* U+00A2 */	CANT_MAP_CHARACTER,	/* 418 */
/* U+00A3 */	CANT_MAP_CHARACTER,	/* 419 */
/* U+00A4 */	0xFD	/*                                 CURRENCY SIGN */,/* 420 */
/* U+00A5 */	CANT_MAP_CHARACTER,	/* 421 */
/* U+00A6 */	CANT_MAP_CHARACTER,	/* 422 */
/* U+00A7 */	CANT_MAP_CHARACTER,	/* 423 */
/* U+00A8 */	CANT_MAP_CHARACTER,	/* 424 */
/* U+00A9 */	CANT_MAP_CHARACTER,	/* 425 */
/* U+00AA */	CANT_MAP_CHARACTER,	/* 426 */
/* U+00AB */	CANT_MAP_CHARACTER,	/* 427 */
/* U+00AC */	CANT_MAP_CHARACTER,	/* 428 */
/* U+00AD */	CANT_MAP_CHARACTER,	/* 429 */
/* U+00AE */	CANT_MAP_CHARACTER,	/* 430 */
/* U+00AF */	CANT_MAP_CHARACTER,	/* 431 */
/* U+00B0 */	0xF8	/*                                   DEGREE SIGN */,/* 432 */
/* U+00B1 */	CANT_MAP_CHARACTER,	/* 433 */
/* U+00B2 */	CANT_MAP_CHARACTER,	/* 434 */
/* U+00B3 */	CANT_MAP_CHARACTER,	/* 435 */
/* U+00B4 */	CANT_MAP_CHARACTER,	/* 436 */
/* U+00B5 */	CANT_MAP_CHARACTER,	/* 437 */
/* U+00B6 */	CANT_MAP_CHARACTER,	/* 438 */
/* U+00B7 */	0xFA	/*                                    MIDDLE DOT */,/* 439 */
/* U+00B8 */	CANT_MAP_CHARACTER,	/* 440 */
/* U+00B9 */	CANT_MAP_CHARACTER,	/* 441 */
/* U+00BA */	CANT_MAP_CHARACTER,	/* 442 */
/* U+00BB */	CANT_MAP_CHARACTER,	/* 443 */
/* U+00BC */	CANT_MAP_CHARACTER,	/* 444 */
/* U+00BD */	CANT_MAP_CHARACTER,	/* 445 */
/* U+00BE */	CANT_MAP_CHARACTER,	/* 446 */
/* U+00BF */	CANT_MAP_CHARACTER,	/* 447 */
/* U+00C0 */	CANT_MAP_CHARACTER,	/* 448 */
/* U+00C1 */	CANT_MAP_CHARACTER,	/* 449 */
/* U+00C2 */	CANT_MAP_CHARACTER,	/* 450 */
/* U+00C3 */	CANT_MAP_CHARACTER,	/* 451 */
/* U+00C4 */	CANT_MAP_CHARACTER,	/* 452 */
/* U+00C5 */	CANT_MAP_CHARACTER,	/* 453 */
/* U+00C6 */	CANT_MAP_CHARACTER,	/* 454 */
/* U+00C7 */	CANT_MAP_CHARACTER,	/* 455 */
/* U+00C8 */	CANT_MAP_CHARACTER,	/* 456 */
/* U+00C9 */	CANT_MAP_CHARACTER,	/* 457 */
/* U+00CA */	CANT_MAP_CHARACTER,	/* 458 */
/* U+00CB */	CANT_MAP_CHARACTER,	/* 459 */
/* U+00CC */	CANT_MAP_CHARACTER,	/* 460 */
/* U+00CD */	CANT_MAP_CHARACTER,	/* 461 */
/* U+00CE */	CANT_MAP_CHARACTER,	/* 462 */
/* U+00CF */	CANT_MAP_CHARACTER,	/* 463 */
/* U+00D0 */	CANT_MAP_CHARACTER,	/* 464 */
/* U+00D1 */	CANT_MAP_CHARACTER,	/* 465 */
/* U+00D2 */	CANT_MAP_CHARACTER,	/* 466 */
/* U+00D3 */	CANT_MAP_CHARACTER,	/* 467 */
/* U+00D4 */	CANT_MAP_CHARACTER,	/* 468 */
/* U+00D5 */	CANT_MAP_CHARACTER,	/* 469 */
/* U+00D6 */	CANT_MAP_CHARACTER,	/* 470 */
/* U+00D7 */	CANT_MAP_CHARACTER,	/* 471 */
/* U+00D8 */	CANT_MAP_CHARACTER,	/* 472 */
/* U+00D9 */	CANT_MAP_CHARACTER,	/* 473 */
/* U+00DA */	CANT_MAP_CHARACTER,	/* 474 */
/* U+00DB */	CANT_MAP_CHARACTER,	/* 475 */
/* U+00DC */	CANT_MAP_CHARACTER,	/* 476 */
/* U+00DD */	CANT_MAP_CHARACTER,	/* 477 */
/* U+00DE */	CANT_MAP_CHARACTER,	/* 478 */
/* U+00DF */	CANT_MAP_CHARACTER,	/* 479 */
/* U+00E0 */	CANT_MAP_CHARACTER,	/* 480 */
/* U+00E1 */	CANT_MAP_CHARACTER,	/* 481 */
/* U+00E2 */	CANT_MAP_CHARACTER,	/* 482 */
/* U+00E3 */	CANT_MAP_CHARACTER,	/* 483 */
/* U+00E4 */	CANT_MAP_CHARACTER,	/* 484 */
/* U+00E5 */	CANT_MAP_CHARACTER,	/* 485 */
/* U+00E6 */	CANT_MAP_CHARACTER,	/* 486 */
/* U+00E7 */	CANT_MAP_CHARACTER,	/* 487 */
/* U+00E8 */	CANT_MAP_CHARACTER,	/* 488 */
/* U+00E9 */	CANT_MAP_CHARACTER,	/* 489 */
/* U+00EA */	CANT_MAP_CHARACTER,	/* 490 */
/* U+00EB */	CANT_MAP_CHARACTER,	/* 491 */
/* U+00EC */	CANT_MAP_CHARACTER,	/* 492 */
/* U+00ED */	CANT_MAP_CHARACTER,	/* 493 */
/* U+00EE */	CANT_MAP_CHARACTER,	/* 494 */
/* U+00EF */	CANT_MAP_CHARACTER,	/* 495 */
/* U+00F0 */	CANT_MAP_CHARACTER,	/* 496 */
/* U+00F1 */	CANT_MAP_CHARACTER,	/* 497 */
/* U+00F2 */	CANT_MAP_CHARACTER,	/* 498 */
/* U+00F3 */	CANT_MAP_CHARACTER,	/* 499 */
/* U+00F4 */	CANT_MAP_CHARACTER,	/* 500 */
/* U+00F5 */	CANT_MAP_CHARACTER,	/* 501 */
/* U+00F6 */	CANT_MAP_CHARACTER,	/* 502 */
/* U+00F7 */	CANT_MAP_CHARACTER,	/* 503 */
/* U+00F8 */	CANT_MAP_CHARACTER,	/* 504 */
/* U+00F9 */	CANT_MAP_CHARACTER,	/* 505 */
/* U+00FA */	CANT_MAP_CHARACTER,	/* 506 */
/* U+00FB */	CANT_MAP_CHARACTER,	/* 507 */
/* U+00FC */	CANT_MAP_CHARACTER,	/* 508 */
/* U+00FD */	CANT_MAP_CHARACTER,	/* 509 */
/* U+00FE */	CANT_MAP_CHARACTER,	/* 510 */
/* U+00FF */	CANT_MAP_CHARACTER,	/* 511 */
/* U+0400 */	CANT_MAP_CHARACTER,	/* 512 */
/* U+0401 */	0xF0	/*                    CYRILLIC CAPITAL LETTER IO */,/* 513 */
/* U+0402 */	CANT_MAP_CHARACTER,	/* 514 */
/* U+0403 */	CANT_MAP_CHARACTER,	/* 515 */
/* U+0404 */	0xF2	/*          CYRILLIC CAPITAL LETTER UKRAINIAN IE */,/* 516 */
/* U+0405 */	CANT_MAP_CHARACTER,	/* 517 */
/* U+0406 */	CANT_MAP_CHARACTER,	/* 518 */
/* U+0407 */	0xF4	/*                    CYRILLIC CAPITAL LETTER YI */,/* 519 */
/* U+0408 */	CANT_MAP_CHARACTER,	/* 520 */
/* U+0409 */	CANT_MAP_CHARACTER,	/* 521 */
/* U+040A */	CANT_MAP_CHARACTER,	/* 522 */
/* U+040B */	CANT_MAP_CHARACTER,	/* 523 */
/* U+040C */	CANT_MAP_CHARACTER,	/* 524 */
/* U+040D */	CANT_MAP_CHARACTER,	/* 525 */
/* U+040E */	0xF6	/*               CYRILLIC CAPITAL LETTER SHORT U */,/* 526 */
/* U+040F */	CANT_MAP_CHARACTER,	/* 527 */
/* U+0410 */	0x80	/*                     CYRILLIC CAPITAL LETTER A */,/* 528 */
/* U+0411 */	0x81	/*                    CYRILLIC CAPITAL LETTER BE */,/* 529 */
/* U+0412 */	0x82	/*                    CYRILLIC CAPITAL LETTER VE */,/* 530 */
/* U+0413 */	0x83	/*                   CYRILLIC CAPITAL LETTER GHE */,/* 531 */
/* U+0414 */	0x84	/*                    CYRILLIC CAPITAL LETTER DE */,/* 532 */
/* U+0415 */	0x85	/*                    CYRILLIC CAPITAL LETTER IE */,/* 533 */
/* U+0416 */	0x86	/*                   CYRILLIC CAPITAL LETTER ZHE */,/* 534 */
/* U+0417 */	0x87	/*                    CYRILLIC CAPITAL LETTER ZE */,/* 535 */
/* U+0418 */	0x88	/*                     CYRILLIC CAPITAL LETTER I */,/* 536 */
/* U+0419 */	0x89	/*               CYRILLIC CAPITAL LETTER SHORT I */,/* 537 */
/* U+041A */	0x8A	/*                    CYRILLIC CAPITAL LETTER KA */,/* 538 */
/* U+041B */	0x8B	/*                    CYRILLIC CAPITAL LETTER EL */,/* 539 */
/* U+041C */	0x8C	/*                    CYRILLIC CAPITAL LETTER EM */,/* 540 */
/* U+041D */	0x8D	/*                    CYRILLIC CAPITAL LETTER EN */,/* 541 */
/* U+041E */	0x8E	/*                     CYRILLIC CAPITAL LETTER O */,/* 542 */
/* U+041F */	0x8F	/*                    CYRILLIC CAPITAL LETTER PE */,/* 543 */
/* U+0420 */	0x90	/*                    CYRILLIC CAPITAL LETTER ER */,/* 544 */
/* U+0421 */	0x91	/*                    CYRILLIC CAPITAL LETTER ES */,/* 545 */
/* U+0422 */	0x92	/*                    CYRILLIC CAPITAL LETTER TE */,/* 546 */
/* U+0423 */	0x93	/*                     CYRILLIC CAPITAL LETTER U */,/* 547 */
/* U+0424 */	0x94	/*                    CYRILLIC CAPITAL LETTER EF */,/* 548 */
/* U+0425 */	0x95	/*                    CYRILLIC CAPITAL LETTER HA */,/* 549 */
/* U+0426 */	0x96	/*                   CYRILLIC CAPITAL LETTER TSE */,/* 550 */
/* U+0427 */	0x97	/*                   CYRILLIC CAPITAL LETTER CHE */,/* 551 */
/* U+0428 */	0x98	/*                   CYRILLIC CAPITAL LETTER SHA */,/* 552 */
/* U+0429 */	0x99	/*                 CYRILLIC CAPITAL LETTER SHCHA */,/* 553 */
/* U+042A */	0x9A	/*             CYRILLIC CAPITAL LETTER HARD SIGN */,/* 554 */
/* U+042B */	0x9B	/*                  CYRILLIC CAPITAL LETTER YERU */,/* 555 */
/* U+042C */	0x9C	/*             CYRILLIC CAPITAL LETTER SOFT SIGN */,/* 556 */
/* U+042D */	0x9D	/*                     CYRILLIC CAPITAL LETTER E */,/* 557 */
/* U+042E */	0x9E	/*                    CYRILLIC CAPITAL LETTER YU */,/* 558 */
/* U+042F */	0x9F	/*                    CYRILLIC CAPITAL LETTER YA */,/* 559 */
/* U+0430 */	0xA0	/*                       CYRILLIC SMALL LETTER A */,/* 560 */
/* U+0431 */	0xA1	/*                      CYRILLIC SMALL LETTER BE */,/* 561 */
/* U+0432 */	0xA2	/*                      CYRILLIC SMALL LETTER VE */,/* 562 */
/* U+0433 */	0xA3	/*                     CYRILLIC SMALL LETTER GHE */,/* 563 */
/* U+0434 */	0xA4	/*                      CYRILLIC SMALL LETTER DE */,/* 564 */
/* U+0435 */	0xA5	/*                      CYRILLIC SMALL LETTER IE */,/* 565 */
/* U+0436 */	0xA6	/*                     CYRILLIC SMALL LETTER ZHE */,/* 566 */
/* U+0437 */	0xA7	/*                      CYRILLIC SMALL LETTER ZE */,/* 567 */
/* U+0438 */	0xA8	/*                       CYRILLIC SMALL LETTER I */,/* 568 */
/* U+0439 */	0xA9	/*                 CYRILLIC SMALL LETTER SHORT I */,/* 569 */
/* U+043A */	0xAA	/*                      CYRILLIC SMALL LETTER KA */,/* 570 */
/* U+043B */	0xAB	/*                      CYRILLIC SMALL LETTER EL */,/* 571 */
/* U+043C */	0xAC	/*                      CYRILLIC SMALL LETTER EM */,/* 572 */
/* U+043D */	0xAD	/*                      CYRILLIC SMALL LETTER EN */,/* 573 */
/* U+043E */	0xAE	/*                       CYRILLIC SMALL LETTER O */,/* 574 */
/* U+043F */	0xAF	/*                      CYRILLIC SMALL LETTER PE */,/* 575 */
/* U+0440 */	0xE0	/*                      CYRILLIC SMALL LETTER ER */,/* 576 */
/* U+0441 */	0xE1	/*                      CYRILLIC SMALL LETTER ES */,/* 577 */
/* U+0442 */	0xE2	/*                      CYRILLIC SMALL LETTER TE */,/* 578 */
/* U+0443 */	0xE3	/*                       CYRILLIC SMALL LETTER U */,/* 579 */
/* U+0444 */	0xE4	/*                      CYRILLIC SMALL LETTER EF */,/* 580 */
/* U+0445 */	0xE5	/*                      CYRILLIC SMALL LETTER HA */,/* 581 */
/* U+0446 */	0xE6	/*                     CYRILLIC SMALL LETTER TSE */,/* 582 */
/* U+0447 */	0xE7	/*                     CYRILLIC SMALL LETTER CHE */,/* 583 */
/* U+0448 */	0xE8	/*                     CYRILLIC SMALL LETTER SHA */,/* 584 */
/* U+0449 */	0xE9	/*                   CYRILLIC SMALL LETTER SHCHA */,/* 585 */
/* U+044A */	0xEA	/*               CYRILLIC SMALL LETTER HARD SIGN */,/* 586 */
/* U+044B */	0xEB	/*                    CYRILLIC SMALL LETTER YERU */,/* 587 */
/* U+044C */	0xEC	/*               CYRILLIC SMALL LETTER SOFT SIGN */,/* 588 */
/* U+044D */	0xED	/*                       CYRILLIC SMALL LETTER E */,/* 589 */
/* U+044E */	0xEE	/*                      CYRILLIC SMALL LETTER YU */,/* 590 */
/* U+044F */	0xEF	/*                      CYRILLIC SMALL LETTER YA */,/* 591 */
/* U+0450 */	CANT_MAP_CHARACTER,	/* 592 */
/* U+0451 */	0xF1	/*                      CYRILLIC SMALL LETTER IO */,/* 593 */
/* U+0452 */	CANT_MAP_CHARACTER,	/* 594 */
/* U+0453 */	CANT_MAP_CHARACTER,	/* 595 */
/* U+0454 */	0xF3	/*            CYRILLIC SMALL LETTER UKRAINIAN IE */,/* 596 */
/* U+0455 */	CANT_MAP_CHARACTER,	/* 597 */
/* U+0456 */	CANT_MAP_CHARACTER,	/* 598 */
/* U+0457 */	0xF5	/*                      CYRILLIC SMALL LETTER YI */,/* 599 */
/* U+0458 */	CANT_MAP_CHARACTER,	/* 600 */
/* U+0459 */	CANT_MAP_CHARACTER,	/* 601 */
/* U+045A */	CANT_MAP_CHARACTER,	/* 602 */
/* U+045B */	CANT_MAP_CHARACTER,	/* 603 */
/* U+045C */	CANT_MAP_CHARACTER,	/* 604 */
/* U+045D */	CANT_MAP_CHARACTER,	/* 605 */
/* U+045E */	0xF7	/*                 CYRILLIC SMALL LETTER SHORT U */,/* 606 */
/* U+045F */	CANT_MAP_CHARACTER,	/* 607 */
/* U+0460 */	CANT_MAP_CHARACTER,	/* 608 */
/* U+0461 */	CANT_MAP_CHARACTER,	/* 609 */
/* U+0462 */	CANT_MAP_CHARACTER,	/* 610 */
/* U+0463 */	CANT_MAP_CHARACTER,	/* 611 */
/* U+0464 */	CANT_MAP_CHARACTER,	/* 612 */
/* U+0465 */	CANT_MAP_CHARACTER,	/* 613 */
/* U+0466 */	CANT_MAP_CHARACTER,	/* 614 */
/* U+0467 */	CANT_MAP_CHARACTER,	/* 615 */
/* U+0468 */	CANT_MAP_CHARACTER,	/* 616 */
/* U+0469 */	CANT_MAP_CHARACTER,	/* 617 */
/* U+046A */	CANT_MAP_CHARACTER,	/* 618 */
/* U+046B */	CANT_MAP_CHARACTER,	/* 619 */
/* U+046C */	CANT_MAP_CHARACTER,	/* 620 */
/* U+046D */	CANT_MAP_CHARACTER,	/* 621 */
/* U+046E */	CANT_MAP_CHARACTER,	/* 622 */
/* U+046F */	CANT_MAP_CHARACTER,	/* 623 */
/* U+0470 */	CANT_MAP_CHARACTER,	/* 624 */
/* U+0471 */	CANT_MAP_CHARACTER,	/* 625 */
/* U+0472 */	CANT_MAP_CHARACTER,	/* 626 */
/* U+0473 */	CANT_MAP_CHARACTER,	/* 627 */
/* U+0474 */	CANT_MAP_CHARACTER,	/* 628 */
/* U+0475 */	CANT_MAP_CHARACTER,	/* 629 */
/* U+0476 */	CANT_MAP_CHARACTER,	/* 630 */
/* U+0477 */	CANT_MAP_CHARACTER,	/* 631 */
/* U+0478 */	CANT_MAP_CHARACTER,	/* 632 */
/* U+0479 */	CANT_MAP_CHARACTER,	/* 633 */
/* U+047A */	CANT_MAP_CHARACTER,	/* 634 */
/* U+047B */	CANT_MAP_CHARACTER,	/* 635 */
/* U+047C */	CANT_MAP_CHARACTER,	/* 636 */
/* U+047D */	CANT_MAP_CHARACTER,	/* 637 */
/* U+047E */	CANT_MAP_CHARACTER,	/* 638 */
/* U+047F */	CANT_MAP_CHARACTER,	/* 639 */
/* U+0480 */	CANT_MAP_CHARACTER,	/* 640 */
/* U+0481 */	CANT_MAP_CHARACTER,	/* 641 */
/* U+0482 */	CANT_MAP_CHARACTER,	/* 642 */
/* U+0483 */	CANT_MAP_CHARACTER,	/* 643 */
/* U+0484 */	CANT_MAP_CHARACTER,	/* 644 */
/* U+0485 */	CANT_MAP_CHARACTER,	/* 645 */
/* U+0486 */	CANT_MAP_CHARACTER,	/* 646 */
/* U+0487 */	CANT_MAP_CHARACTER,	/* 647 */
/* U+0488 */	CANT_MAP_CHARACTER,	/* 648 */
/* U+0489 */	CANT_MAP_CHARACTER,	/* 649 */
/* U+048A */	CANT_MAP_CHARACTER,	/* 650 */
/* U+048B */	CANT_MAP_CHARACTER,	/* 651 */
/* U+048C */	CANT_MAP_CHARACTER,	/* 652 */
/* U+048D */	CANT_MAP_CHARACTER,	/* 653 */
/* U+048E */	CANT_MAP_CHARACTER,	/* 654 */
/* U+048F */	CANT_MAP_CHARACTER,	/* 655 */
/* U+0490 */	CANT_MAP_CHARACTER,	/* 656 */
/* U+0491 */	CANT_MAP_CHARACTER,	/* 657 */
/* U+0492 */	CANT_MAP_CHARACTER,	/* 658 */
/* U+0493 */	CANT_MAP_CHARACTER,	/* 659 */
/* U+0494 */	CANT_MAP_CHARACTER,	/* 660 */
/* U+0495 */	CANT_MAP_CHARACTER,	/* 661 */
/* U+0496 */	CANT_MAP_CHARACTER,	/* 662 */
/* U+0497 */	CANT_MAP_CHARACTER,	/* 663 */
/* U+0498 */	CANT_MAP_CHARACTER,	/* 664 */
/* U+0499 */	CANT_MAP_CHARACTER,	/* 665 */
/* U+049A */	CANT_MAP_CHARACTER,	/* 666 */
/* U+049B */	CANT_MAP_CHARACTER,	/* 667 */
/* U+049C */	CANT_MAP_CHARACTER,	/* 668 */
/* U+049D */	CANT_MAP_CHARACTER,	/* 669 */
/* U+049E */	CANT_MAP_CHARACTER,	/* 670 */
/* U+049F */	CANT_MAP_CHARACTER,	/* 671 */
/* U+04A0 */	CANT_MAP_CHARACTER,	/* 672 */
/* U+04A1 */	CANT_MAP_CHARACTER,	/* 673 */
/* U+04A2 */	CANT_MAP_CHARACTER,	/* 674 */
/* U+04A3 */	CANT_MAP_CHARACTER,	/* 675 */
/* U+04A4 */	CANT_MAP_CHARACTER,	/* 676 */
/* U+04A5 */	CANT_MAP_CHARACTER,	/* 677 */
/* U+04A6 */	CANT_MAP_CHARACTER,	/* 678 */
/* U+04A7 */	CANT_MAP_CHARACTER,	/* 679 */
/* U+04A8 */	CANT_MAP_CHARACTER,	/* 680 */
/* U+04A9 */	CANT_MAP_CHARACTER,	/* 681 */
/* U+04AA */	CANT_MAP_CHARACTER,	/* 682 */
/* U+04AB */	CANT_MAP_CHARACTER,	/* 683 */
/* U+04AC */	CANT_MAP_CHARACTER,	/* 684 */
/* U+04AD */	CANT_MAP_CHARACTER,	/* 685 */
/* U+04AE */	CANT_MAP_CHARACTER,	/* 686 */
/* U+04AF */	CANT_MAP_CHARACTER,	/* 687 */
/* U+04B0 */	CANT_MAP_CHARACTER,	/* 688 */
/* U+04B1 */	CANT_MAP_CHARACTER,	/* 689 */
/* U+04B2 */	CANT_MAP_CHARACTER,	/* 690 */
/* U+04B3 */	CANT_MAP_CHARACTER,	/* 691 */
/* U+04B4 */	CANT_MAP_CHARACTER,	/* 692 */
/* U+04B5 */	CANT_MAP_CHARACTER,	/* 693 */
/* U+04B6 */	CANT_MAP_CHARACTER,	/* 694 */
/* U+04B7 */	CANT_MAP_CHARACTER,	/* 695 */
/* U+04B8 */	CANT_MAP_CHARACTER,	/* 696 */
/* U+04B9 */	CANT_MAP_CHARACTER,	/* 697 */
/* U+04BA */	CANT_MAP_CHARACTER,	/* 698 */
/* U+04BB */	CANT_MAP_CHARACTER,	/* 699 */
/* U+04BC */	CANT_MAP_CHARACTER,	/* 700 */
/* U+04BD */	CANT_MAP_CHARACTER,	/* 701 */
/* U+04BE */	CANT_MAP_CHARACTER,	/* 702 */
/* U+04BF */	CANT_MAP_CHARACTER,	/* 703 */
/* U+04C0 */	CANT_MAP_CHARACTER,	/* 704 */
/* U+04C1 */	CANT_MAP_CHARACTER,	/* 705 */
/* U+04C2 */	CANT_MAP_CHARACTER,	/* 706 */
/* U+04C3 */	CANT_MAP_CHARACTER,	/* 707 */
/* U+04C4 */	CANT_MAP_CHARACTER,	/* 708 */
/* U+04C5 */	CANT_MAP_CHARACTER,	/* 709 */
/* U+04C6 */	CANT_MAP_CHARACTER,	/* 710 */
/* U+04C7 */	CANT_MAP_CHARACTER,	/* 711 */
/* U+04C8 */	CANT_MAP_CHARACTER,	/* 712 */
/* U+04C9 */	CANT_MAP_CHARACTER,	/* 713 */
/* U+04CA */	CANT_MAP_CHARACTER,	/* 714 */
/* U+04CB */	CANT_MAP_CHARACTER,	/* 715 */
/* U+04CC */	CANT_MAP_CHARACTER,	/* 716 */
/* U+04CD */	CANT_MAP_CHARACTER,	/* 717 */
/* U+04CE */	CANT_MAP_CHARACTER,	/* 718 */
/* U+04CF */	CANT_MAP_CHARACTER,	/* 719 */
/* U+04D0 */	CANT_MAP_CHARACTER,	/* 720 */
/* U+04D1 */	CANT_MAP_CHARACTER,	/* 721 */
/* U+04D2 */	CANT_MAP_CHARACTER,	/* 722 */
/* U+04D3 */	CANT_MAP_CHARACTER,	/* 723 */
/* U+04D4 */	CANT_MAP_CHARACTER,	/* 724 */
/* U+04D5 */	CANT_MAP_CHARACTER,	/* 725 */
/* U+04D6 */	CANT_MAP_CHARACTER,	/* 726 */
/* U+04D7 */	CANT_MAP_CHARACTER,	/* 727 */
/* U+04D8 */	CANT_MAP_CHARACTER,	/* 728 */
/* U+04D9 */	CANT_MAP_CHARACTER,	/* 729 */
/* U+04DA */	CANT_MAP_CHARACTER,	/* 730 */
/* U+04DB */	CANT_MAP_CHARACTER,	/* 731 */
/* U+04DC */	CANT_MAP_CHARACTER,	/* 732 */
/* U+04DD */	CANT_MAP_CHARACTER,	/* 733 */
/* U+04DE */	CANT_MAP_CHARACTER,	/* 734 */
/* U+04DF */	CANT_MAP_CHARACTER,	/* 735 */
/* U+04E0 */	CANT_MAP_CHARACTER,	/* 736 */
/* U+04E1 */	CANT_MAP_CHARACTER,	/* 737 */
/* U+04E2 */	CANT_MAP_CHARACTER,	/* 738 */
/* U+04E3 */	CANT_MAP_CHARACTER,	/* 739 */
/* U+04E4 */	CANT_MAP_CHARACTER,	/* 740 */
/* U+04E5 */	CANT_MAP_CHARACTER,	/* 741 */
/* U+04E6 */	CANT_MAP_CHARACTER,	/* 742 */
/* U+04E7 */	CANT_MAP_CHARACTER,	/* 743 */
/* U+04E8 */	CANT_MAP_CHARACTER,	/* 744 */
/* U+04E9 */	CANT_MAP_CHARACTER,	/* 745 */
/* U+04EA */	CANT_MAP_CHARACTER,	/* 746 */
/* U+04EB */	CANT_MAP_CHARACTER,	/* 747 */
/* U+04EC */	CANT_MAP_CHARACTER,	/* 748 */
/* U+04ED */	CANT_MAP_CHARACTER,	/* 749 */
/* U+04EE */	CANT_MAP_CHARACTER,	/* 750 */
/* U+04EF */	CANT_MAP_CHARACTER,	/* 751 */
/* U+04F0 */	CANT_MAP_CHARACTER,	/* 752 */
/* U+04F1 */	CANT_MAP_CHARACTER,	/* 753 */
/* U+04F2 */	CANT_MAP_CHARACTER,	/* 754 */
/* U+04F3 */	CANT_MAP_CHARACTER,	/* 755 */
/* U+04F4 */	CANT_MAP_CHARACTER,	/* 756 */
/* U+04F5 */	CANT_MAP_CHARACTER,	/* 757 */
/* U+04F6 */	CANT_MAP_CHARACTER,	/* 758 */
/* U+04F7 */	CANT_MAP_CHARACTER,	/* 759 */
/* U+04F8 */	CANT_MAP_CHARACTER,	/* 760 */
/* U+04F9 */	CANT_MAP_CHARACTER,	/* 761 */
/* U+04FA */	CANT_MAP_CHARACTER,	/* 762 */
/* U+04FB */	CANT_MAP_CHARACTER,	/* 763 */
/* U+04FC */	CANT_MAP_CHARACTER,	/* 764 */
/* U+04FD */	CANT_MAP_CHARACTER,	/* 765 */
/* U+04FE */	CANT_MAP_CHARACTER,	/* 766 */
/* U+04FF */	CANT_MAP_CHARACTER,	/* 767 */
/* U+2100 */	CANT_MAP_CHARACTER,	/* 768 */
/* U+2101 */	CANT_MAP_CHARACTER,	/* 769 */
/* U+2102 */	CANT_MAP_CHARACTER,	/* 770 */
/* U+2103 */	CANT_MAP_CHARACTER,	/* 771 */
/* U+2104 */	CANT_MAP_CHARACTER,	/* 772 */
/* U+2105 */	CANT_MAP_CHARACTER,	/* 773 */
/* U+2106 */	CANT_MAP_CHARACTER,	/* 774 */
/* U+2107 */	CANT_MAP_CHARACTER,	/* 775 */
/* U+2108 */	CANT_MAP_CHARACTER,	/* 776 */
/* U+2109 */	CANT_MAP_CHARACTER,	/* 777 */
/* U+210A */	CANT_MAP_CHARACTER,	/* 778 */
/* U+210B */	CANT_MAP_CHARACTER,	/* 779 */
/* U+210C */	CANT_MAP_CHARACTER,	/* 780 */
/* U+210D */	CANT_MAP_CHARACTER,	/* 781 */
/* U+210E */	CANT_MAP_CHARACTER,	/* 782 */
/* U+210F */	CANT_MAP_CHARACTER,	/* 783 */
/* U+2110 */	CANT_MAP_CHARACTER,	/* 784 */
/* U+2111 */	CANT_MAP_CHARACTER,	/* 785 */
/* U+2112 */	CANT_MAP_CHARACTER,	/* 786 */
/* U+2113 */	CANT_MAP_CHARACTER,	/* 787 */
/* U+2114 */	CANT_MAP_CHARACTER,	/* 788 */
/* U+2115 */	CANT_MAP_CHARACTER,	/* 789 */
/* U+2116 */	0xFC	/*                                   NUMERO SIGN */,/* 790 */
/* U+2117 */	CANT_MAP_CHARACTER,	/* 791 */
/* U+2118 */	CANT_MAP_CHARACTER,	/* 792 */
/* U+2119 */	CANT_MAP_CHARACTER,	/* 793 */
/* U+211A */	CANT_MAP_CHARACTER,	/* 794 */
/* U+211B */	CANT_MAP_CHARACTER,	/* 795 */
/* U+211C */	CANT_MAP_CHARACTER,	/* 796 */
/* U+211D */	CANT_MAP_CHARACTER,	/* 797 */
/* U+211E */	CANT_MAP_CHARACTER,	/* 798 */
/* U+211F */	CANT_MAP_CHARACTER,	/* 799 */
/* U+2120 */	CANT_MAP_CHARACTER,	/* 800 */
/* U+2121 */	CANT_MAP_CHARACTER,	/* 801 */
/* U+2122 */	CANT_MAP_CHARACTER,	/* 802 */
/* U+2123 */	CANT_MAP_CHARACTER,	/* 803 */
/* U+2124 */	CANT_MAP_CHARACTER,	/* 804 */
/* U+2125 */	CANT_MAP_CHARACTER,	/* 805 */
/* U+2126 */	CANT_MAP_CHARACTER,	/* 806 */
/* U+2127 */	CANT_MAP_CHARACTER,	/* 807 */
/* U+2128 */	CANT_MAP_CHARACTER,	/* 808 */
/* U+2129 */	CANT_MAP_CHARACTER,	/* 809 */
/* U+212A */	CANT_MAP_CHARACTER,	/* 810 */
/* U+212B */	CANT_MAP_CHARACTER,	/* 811 */
/* U+212C */	CANT_MAP_CHARACTER,	/* 812 */
/* U+212D */	CANT_MAP_CHARACTER,	/* 813 */
/* U+212E */	CANT_MAP_CHARACTER,	/* 814 */
/* U+212F */	CANT_MAP_CHARACTER,	/* 815 */
/* U+2130 */	CANT_MAP_CHARACTER,	/* 816 */
/* U+2131 */	CANT_MAP_CHARACTER,	/* 817 */
/* U+2132 */	CANT_MAP_CHARACTER,	/* 818 */
/* U+2133 */	CANT_MAP_CHARACTER,	/* 819 */
/* U+2134 */	CANT_MAP_CHARACTER,	/* 820 */
/* U+2135 */	CANT_MAP_CHARACTER,	/* 821 */
/* U+2136 */	CANT_MAP_CHARACTER,	/* 822 */
/* U+2137 */	CANT_MAP_CHARACTER,	/* 823 */
/* U+2138 */	CANT_MAP_CHARACTER,	/* 824 */
/* U+2139 */	CANT_MAP_CHARACTER,	/* 825 */
/* U+213A */	CANT_MAP_CHARACTER,	/* 826 */
/* U+213B */	CANT_MAP_CHARACTER,	/* 827 */
/* U+213C */	CANT_MAP_CHARACTER,	/* 828 */
/* U+213D */	CANT_MAP_CHARACTER,	/* 829 */
/* U+213E */	CANT_MAP_CHARACTER,	/* 830 */
/* U+213F */	CANT_MAP_CHARACTER,	/* 831 */
/* U+2140 */	CANT_MAP_CHARACTER,	/* 832 */
/* U+2141 */	CANT_MAP_CHARACTER,	/* 833 */
/* U+2142 */	CANT_MAP_CHARACTER,	/* 834 */
/* U+2143 */	CANT_MAP_CHARACTER,	/* 835 */
/* U+2144 */	CANT_MAP_CHARACTER,	/* 836 */
/* U+2145 */	CANT_MAP_CHARACTER,	/* 837 */
/* U+2146 */	CANT_MAP_CHARACTER,	/* 838 */
/* U+2147 */	CANT_MAP_CHARACTER,	/* 839 */
/* U+2148 */	CANT_MAP_CHARACTER,	/* 840 */
/* U+2149 */	CANT_MAP_CHARACTER,	/* 841 */
/* U+214A */	CANT_MAP_CHARACTER,	/* 842 */
/* U+214B */	CANT_MAP_CHARACTER,	/* 843 */
/* U+214C */	CANT_MAP_CHARACTER,	/* 844 */
/* U+214D */	CANT_MAP_CHARACTER,	/* 845 */
/* U+214E */	CANT_MAP_CHARACTER,	/* 846 */
/* U+214F */	CANT_MAP_CHARACTER,	/* 847 */
/* U+2150 */	CANT_MAP_CHARACTER,	/* 848 */
/* U+2151 */	CANT_MAP_CHARACTER,	/* 849 */
/* U+2152 */	CANT_MAP_CHARACTER,	/* 850 */
/* U+2153 */	CANT_MAP_CHARACTER,	/* 851 */
/* U+2154 */	CANT_MAP_CHARACTER,	/* 852 */
/* U+2155 */	CANT_MAP_CHARACTER,	/* 853 */
/* U+2156 */	CANT_MAP_CHARACTER,	/* 854 */
/* U+2157 */	CANT_MAP_CHARACTER,	/* 855 */
/* U+2158 */	CANT_MAP_CHARACTER,	/* 856 */
/* U+2159 */	CANT_MAP_CHARACTER,	/* 857 */
/* U+215A */	CANT_MAP_CHARACTER,	/* 858 */
/* U+215B */	CANT_MAP_CHARACTER,	/* 859 */
/* U+215C */	CANT_MAP_CHARACTER,	/* 860 */
/* U+215D */	CANT_MAP_CHARACTER,	/* 861 */
/* U+215E */	CANT_MAP_CHARACTER,	/* 862 */
/* U+215F */	CANT_MAP_CHARACTER,	/* 863 */
/* U+2160 */	CANT_MAP_CHARACTER,	/* 864 */
/* U+2161 */	CANT_MAP_CHARACTER,	/* 865 */
/* U+2162 */	CANT_MAP_CHARACTER,	/* 866 */
/* U+2163 */	CANT_MAP_CHARACTER,	/* 867 */
/* U+2164 */	CANT_MAP_CHARACTER,	/* 868 */
/* U+2165 */	CANT_MAP_CHARACTER,	/* 869 */
/* U+2166 */	CANT_MAP_CHARACTER,	/* 870 */
/* U+2167 */	CANT_MAP_CHARACTER,	/* 871 */
/* U+2168 */	CANT_MAP_CHARACTER,	/* 872 */
/* U+2169 */	CANT_MAP_CHARACTER,	/* 873 */
/* U+216A */	CANT_MAP_CHARACTER,	/* 874 */
/* U+216B */	CANT_MAP_CHARACTER,	/* 875 */
/* U+216C */	CANT_MAP_CHARACTER,	/* 876 */
/* U+216D */	CANT_MAP_CHARACTER,	/* 877 */
/* U+216E */	CANT_MAP_CHARACTER,	/* 878 */
/* U+216F */	CANT_MAP_CHARACTER,	/* 879 */
/* U+2170 */	CANT_MAP_CHARACTER,	/* 880 */
/* U+2171 */	CANT_MAP_CHARACTER,	/* 881 */
/* U+2172 */	CANT_MAP_CHARACTER,	/* 882 */
/* U+2173 */	CANT_MAP_CHARACTER,	/* 883 */
/* U+2174 */	CANT_MAP_CHARACTER,	/* 884 */
/* U+2175 */	CANT_MAP_CHARACTER,	/* 885 */
/* U+2176 */	CANT_MAP_CHARACTER,	/* 886 */
/* U+2177 */	CANT_MAP_CHARACTER,	/* 887 */
/* U+2178 */	CANT_MAP_CHARACTER,	/* 888 */
/* U+2179 */	CANT_MAP_CHARACTER,	/* 889 */
/* U+217A */	CANT_MAP_CHARACTER,	/* 890 */
/* U+217B */	CANT_MAP_CHARACTER,	/* 891 */
/* U+217C */	CANT_MAP_CHARACTER,	/* 892 */
/* U+217D */	CANT_MAP_CHARACTER,	/* 893 */
/* U+217E */	CANT_MAP_CHARACTER,	/* 894 */
/* U+217F */	CANT_MAP_CHARACTER,	/* 895 */
/* U+2180 */	CANT_MAP_CHARACTER,	/* 896 */
/* U+2181 */	CANT_MAP_CHARACTER,	/* 897 */
/* U+2182 */	CANT_MAP_CHARACTER,	/* 898 */
/* U+2183 */	CANT_MAP_CHARACTER,	/* 899 */
/* U+2184 */	CANT_MAP_CHARACTER,	/* 900 */
/* U+2185 */	CANT_MAP_CHARACTER,	/* 901 */
/* U+2186 */	CANT_MAP_CHARACTER,	/* 902 */
/* U+2187 */	CANT_MAP_CHARACTER,	/* 903 */
/* U+2188 */	CANT_MAP_CHARACTER,	/* 904 */
/* U+2189 */	CANT_MAP_CHARACTER,	/* 905 */
/* U+218A */	CANT_MAP_CHARACTER,	/* 906 */
/* U+218B */	CANT_MAP_CHARACTER,	/* 907 */
/* U+218C */	CANT_MAP_CHARACTER,	/* 908 */
/* U+218D */	CANT_MAP_CHARACTER,	/* 909 */
/* U+218E */	CANT_MAP_CHARACTER,	/* 910 */
/* U+218F */	CANT_MAP_CHARACTER,	/* 911 */
/* U+2190 */	CANT_MAP_CHARACTER,	/* 912 */
/* U+2191 */	CANT_MAP_CHARACTER,	/* 913 */
/* U+2192 */	CANT_MAP_CHARACTER,	/* 914 */
/* U+2193 */	CANT_MAP_CHARACTER,	/* 915 */
/* U+2194 */	CANT_MAP_CHARACTER,	/* 916 */
/* U+2195 */	CANT_MAP_CHARACTER,	/* 917 */
/* U+2196 */	CANT_MAP_CHARACTER,	/* 918 */
/* U+2197 */	CANT_MAP_CHARACTER,	/* 919 */
/* U+2198 */	CANT_MAP_CHARACTER,	/* 920 */
/* U+2199 */	CANT_MAP_CHARACTER,	/* 921 */
/* U+219A */	CANT_MAP_CHARACTER,	/* 922 */
/* U+219B */	CANT_MAP_CHARACTER,	/* 923 */
/* U+219C */	CANT_MAP_CHARACTER,	/* 924 */
/* U+219D */	CANT_MAP_CHARACTER,	/* 925 */
/* U+219E */	CANT_MAP_CHARACTER,	/* 926 */
/* U+219F */	CANT_MAP_CHARACTER,	/* 927 */
/* U+21A0 */	CANT_MAP_CHARACTER,	/* 928 */
/* U+21A1 */	CANT_MAP_CHARACTER,	/* 929 */
/* U+21A2 */	CANT_MAP_CHARACTER,	/* 930 */
/* U+21A3 */	CANT_MAP_CHARACTER,	/* 931 */
/* U+21A4 */	CANT_MAP_CHARACTER,	/* 932 */
/* U+21A5 */	CANT_MAP_CHARACTER,	/* 933 */
/* U+21A6 */	CANT_MAP_CHARACTER,	/* 934 */
/* U+21A7 */	CANT_MAP_CHARACTER,	/* 935 */
/* U+21A8 */	CANT_MAP_CHARACTER,	/* 936 */
/* U+21A9 */	CANT_MAP_CHARACTER,	/* 937 */
/* U+21AA */	CANT_MAP_CHARACTER,	/* 938 */
/* U+21AB */	CANT_MAP_CHARACTER,	/* 939 */
/* U+21AC */	CANT_MAP_CHARACTER,	/* 940 */
/* U+21AD */	CANT_MAP_CHARACTER,	/* 941 */
/* U+21AE */	CANT_MAP_CHARACTER,	/* 942 */
/* U+21AF */	CANT_MAP_CHARACTER,	/* 943 */
/* U+21B0 */	CANT_MAP_CHARACTER,	/* 944 */
/* U+21B1 */	CANT_MAP_CHARACTER,	/* 945 */
/* U+21B2 */	CANT_MAP_CHARACTER,	/* 946 */
/* U+21B3 */	CANT_MAP_CHARACTER,	/* 947 */
/* U+21B4 */	CANT_MAP_CHARACTER,	/* 948 */
/* U+21B5 */	CANT_MAP_CHARACTER,	/* 949 */
/* U+21B6 */	CANT_MAP_CHARACTER,	/* 950 */
/* U+21B7 */	CANT_MAP_CHARACTER,	/* 951 */
/* U+21B8 */	CANT_MAP_CHARACTER,	/* 952 */
/* U+21B9 */	CANT_MAP_CHARACTER,	/* 953 */
/* U+21BA */	CANT_MAP_CHARACTER,	/* 954 */
/* U+21BB */	CANT_MAP_CHARACTER,	/* 955 */
/* U+21BC */	CANT_MAP_CHARACTER,	/* 956 */
/* U+21BD */	CANT_MAP_CHARACTER,	/* 957 */
/* U+21BE */	CANT_MAP_CHARACTER,	/* 958 */
/* U+21BF */	CANT_MAP_CHARACTER,	/* 959 */
/* U+21C0 */	CANT_MAP_CHARACTER,	/* 960 */
/* U+21C1 */	CANT_MAP_CHARACTER,	/* 961 */
/* U+21C2 */	CANT_MAP_CHARACTER,	/* 962 */
/* U+21C3 */	CANT_MAP_CHARACTER,	/* 963 */
/* U+21C4 */	CANT_MAP_CHARACTER,	/* 964 */
/* U+21C5 */	CANT_MAP_CHARACTER,	/* 965 */
/* U+21C6 */	CANT_MAP_CHARACTER,	/* 966 */
/* U+21C7 */	CANT_MAP_CHARACTER,	/* 967 */
/* U+21C8 */	CANT_MAP_CHARACTER,	/* 968 */
/* U+21C9 */	CANT_MAP_CHARACTER,	/* 969 */
/* U+21CA */	CANT_MAP_CHARACTER,	/* 970 */
/* U+21CB */	CANT_MAP_CHARACTER,	/* 971 */
/* U+21CC */	CANT_MAP_CHARACTER,	/* 972 */
/* U+21CD */	CANT_MAP_CHARACTER,	/* 973 */
/* U+21CE */	CANT_MAP_CHARACTER,	/* 974 */
/* U+21CF */	CANT_MAP_CHARACTER,	/* 975 */
/* U+21D0 */	CANT_MAP_CHARACTER,	/* 976 */
/* U+21D1 */	CANT_MAP_CHARACTER,	/* 977 */
/* U+21D2 */	CANT_MAP_CHARACTER,	/* 978 */
/* U+21D3 */	CANT_MAP_CHARACTER,	/* 979 */
/* U+21D4 */	CANT_MAP_CHARACTER,	/* 980 */
/* U+21D5 */	CANT_MAP_CHARACTER,	/* 981 */
/* U+21D6 */	CANT_MAP_CHARACTER,	/* 982 */
/* U+21D7 */	CANT_MAP_CHARACTER,	/* 983 */
/* U+21D8 */	CANT_MAP_CHARACTER,	/* 984 */
/* U+21D9 */	CANT_MAP_CHARACTER,	/* 985 */
/* U+21DA */	CANT_MAP_CHARACTER,	/* 986 */
/* U+21DB */	CANT_MAP_CHARACTER,	/* 987 */
/* U+21DC */	CANT_MAP_CHARACTER,	/* 988 */
/* U+21DD */	CANT_MAP_CHARACTER,	/* 989 */
/* U+21DE */	CANT_MAP_CHARACTER,	/* 990 */
/* U+21DF */	CANT_MAP_CHARACTER,	/* 991 */
/* U+21E0 */	CANT_MAP_CHARACTER,	/* 992 */
/* U+21E1 */	CANT_MAP_CHARACTER,	/* 993 */
/* U+21E2 */	CANT_MAP_CHARACTER,	/* 994 */
/* U+21E3 */	CANT_MAP_CHARACTER,	/* 995 */
/* U+21E4 */	CANT_MAP_CHARACTER,	/* 996 */
/* U+21E5 */	CANT_MAP_CHARACTER,	/* 997 */
/* U+21E6 */	CANT_MAP_CHARACTER,	/* 998 */
/* U+21E7 */	CANT_MAP_CHARACTER,	/* 999 */
/* U+21E8 */	CANT_MAP_CHARACTER,	/* 1000 */
/* U+21E9 */	CANT_MAP_CHARACTER,	/* 1001 */
/* U+21EA */	CANT_MAP_CHARACTER,	/* 1002 */
/* U+21EB */	CANT_MAP_CHARACTER,	/* 1003 */
/* U+21EC */	CANT_MAP_CHARACTER,	/* 1004 */
/* U+21ED */	CANT_MAP_CHARACTER,	/* 1005 */
/* U+21EE */	CANT_MAP_CHARACTER,	/* 1006 */
/* U+21EF */	CANT_MAP_CHARACTER,	/* 1007 */
/* U+21F0 */	CANT_MAP_CHARACTER,	/* 1008 */
/* U+21F1 */	CANT_MAP_CHARACTER,	/* 1009 */
/* U+21F2 */	CANT_MAP_CHARACTER,	/* 1010 */
/* U+21F3 */	CANT_MAP_CHARACTER,	/* 1011 */
/* U+21F4 */	CANT_MAP_CHARACTER,	/* 1012 */
/* U+21F5 */	CANT_MAP_CHARACTER,	/* 1013 */
/* U+21F6 */	CANT_MAP_CHARACTER,	/* 1014 */
/* U+21F7 */	CANT_MAP_CHARACTER,	/* 1015 */
/* U+21F8 */	CANT_MAP_CHARACTER,	/* 1016 */
/* U+21F9 */	CANT_MAP_CHARACTER,	/* 1017 */
/* U+21FA */	CANT_MAP_CHARACTER,	/* 1018 */
/* U+21FB */	CANT_MAP_CHARACTER,	/* 1019 */
/* U+21FC */	CANT_MAP_CHARACTER,	/* 1020 */
/* U+21FD */	CANT_MAP_CHARACTER,	/* 1021 */
/* U+21FE */	CANT_MAP_CHARACTER,	/* 1022 */
/* U+21FF */	CANT_MAP_CHARACTER,	/* 1023 */
/* U+2200 */	CANT_MAP_CHARACTER,	/* 1024 */
/* U+2201 */	CANT_MAP_CHARACTER,	/* 1025 */
/* U+2202 */	CANT_MAP_CHARACTER,	/* 1026 */
/* U+2203 */	CANT_MAP_CHARACTER,	/* 1027 */
/* U+2204 */	CANT_MAP_CHARACTER,	/* 1028 */
/* U+2205 */	CANT_MAP_CHARACTER,	/* 1029 */
/* U+2206 */	CANT_MAP_CHARACTER,	/* 1030 */
/* U+2207 */	CANT_MAP_CHARACTER,	/* 1031 */
/* U+2208 */	CANT_MAP_CHARACTER,	/* 1032 */
/* U+2209 */	CANT_MAP_CHARACTER,	/* 1033 */
/* U+220A */	CANT_MAP_CHARACTER,	/* 1034 */
/* U+220B */	CANT_MAP_CHARACTER,	/* 1035 */
/* U+220C */	CANT_MAP_CHARACTER,	/* 1036 */
/* U+220D */	CANT_MAP_CHARACTER,	/* 1037 */
/* U+220E */	CANT_MAP_CHARACTER,	/* 1038 */
/* U+220F */	CANT_MAP_CHARACTER,	/* 1039 */
/* U+2210 */	CANT_MAP_CHARACTER,	/* 1040 */
/* U+2211 */	CANT_MAP_CHARACTER,	/* 1041 */
/* U+2212 */	CANT_MAP_CHARACTER,	/* 1042 */
/* U+2213 */	CANT_MAP_CHARACTER,	/* 1043 */
/* U+2214 */	CANT_MAP_CHARACTER,	/* 1044 */
/* U+2215 */	CANT_MAP_CHARACTER,	/* 1045 */
/* U+2216 */	CANT_MAP_CHARACTER,	/* 1046 */
/* U+2217 */	CANT_MAP_CHARACTER,	/* 1047 */
/* U+2218 */	CANT_MAP_CHARACTER,	/* 1048 */
/* U+2219 */	0xF9	/*                               BULLET OPERATOR */,/* 1049 */
/* U+221A */	0xFB	/*                                   SQUARE ROOT */,/* 1050 */
/* U+221B */	CANT_MAP_CHARACTER,	/* 1051 */
/* U+221C */	CANT_MAP_CHARACTER,	/* 1052 */
/* U+221D */	CANT_MAP_CHARACTER,	/* 1053 */
/* U+221E */	CANT_MAP_CHARACTER,	/* 1054 */
/* U+221F */	CANT_MAP_CHARACTER,	/* 1055 */
/* U+2220 */	CANT_MAP_CHARACTER,	/* 1056 */
/* U+2221 */	CANT_MAP_CHARACTER,	/* 1057 */
/* U+2222 */	CANT_MAP_CHARACTER,	/* 1058 */
/* U+2223 */	CANT_MAP_CHARACTER,	/* 1059 */
/* U+2224 */	CANT_MAP_CHARACTER,	/* 1060 */
/* U+2225 */	CANT_MAP_CHARACTER,	/* 1061 */
/* U+2226 */	CANT_MAP_CHARACTER,	/* 1062 */
/* U+2227 */	CANT_MAP_CHARACTER,	/* 1063 */
/* U+2228 */	CANT_MAP_CHARACTER,	/* 1064 */
/* U+2229 */	CANT_MAP_CHARACTER,	/* 1065 */
/* U+222A */	CANT_MAP_CHARACTER,	/* 1066 */
/* U+222B */	CANT_MAP_CHARACTER,	/* 1067 */
/* U+222C */	CANT_MAP_CHARACTER,	/* 1068 */
/* U+222D */	CANT_MAP_CHARACTER,	/* 1069 */
/* U+222E */	CANT_MAP_CHARACTER,	/* 1070 */
/* U+222F */	CANT_MAP_CHARACTER,	/* 1071 */
/* U+2230 */	CANT_MAP_CHARACTER,	/* 1072 */
/* U+2231 */	CANT_MAP_CHARACTER,	/* 1073 */
/* U+2232 */	CANT_MAP_CHARACTER,	/* 1074 */
/* U+2233 */	CANT_MAP_CHARACTER,	/* 1075 */
/* U+2234 */	CANT_MAP_CHARACTER,	/* 1076 */
/* U+2235 */	CANT_MAP_CHARACTER,	/* 1077 */
/* U+2236 */	CANT_MAP_CHARACTER,	/* 1078 */
/* U+2237 */	CANT_MAP_CHARACTER,	/* 1079 */
/* U+2238 */	CANT_MAP_CHARACTER,	/* 1080 */
/* U+2239 */	CANT_MAP_CHARACTER,	/* 1081 */
/* U+223A */	CANT_MAP_CHARACTER,	/* 1082 */
/* U+223B */	CANT_MAP_CHARACTER,	/* 1083 */
/* U+223C */	CANT_MAP_CHARACTER,	/* 1084 */
/* U+223D */	CANT_MAP_CHARACTER,	/* 1085 */
/* U+223E */	CANT_MAP_CHARACTER,	/* 1086 */
/* U+223F */	CANT_MAP_CHARACTER,	/* 1087 */
/* U+2240 */	CANT_MAP_CHARACTER,	/* 1088 */
/* U+2241 */	CANT_MAP_CHARACTER,	/* 1089 */
/* U+2242 */	CANT_MAP_CHARACTER,	/* 1090 */
/* U+2243 */	CANT_MAP_CHARACTER,	/* 1091 */
/* U+2244 */	CANT_MAP_CHARACTER,	/* 1092 */
/* U+2245 */	CANT_MAP_CHARACTER,	/* 1093 */
/* U+2246 */	CANT_MAP_CHARACTER,	/* 1094 */
/* U+2247 */	CANT_MAP_CHARACTER,	/* 1095 */
/* U+2248 */	CANT_MAP_CHARACTER,	/* 1096 */
/* U+2249 */	CANT_MAP_CHARACTER,	/* 1097 */
/* U+224A */	CANT_MAP_CHARACTER,	/* 1098 */
/* U+224B */	CANT_MAP_CHARACTER,	/* 1099 */
/* U+224C */	CANT_MAP_CHARACTER,	/* 1100 */
/* U+224D */	CANT_MAP_CHARACTER,	/* 1101 */
/* U+224E */	CANT_MAP_CHARACTER,	/* 1102 */
/* U+224F */	CANT_MAP_CHARACTER,	/* 1103 */
/* U+2250 */	CANT_MAP_CHARACTER,	/* 1104 */
/* U+2251 */	CANT_MAP_CHARACTER,	/* 1105 */
/* U+2252 */	CANT_MAP_CHARACTER,	/* 1106 */
/* U+2253 */	CANT_MAP_CHARACTER,	/* 1107 */
/* U+2254 */	CANT_MAP_CHARACTER,	/* 1108 */
/* U+2255 */	CANT_MAP_CHARACTER,	/* 1109 */
/* U+2256 */	CANT_MAP_CHARACTER,	/* 1110 */
/* U+2257 */	CANT_MAP_CHARACTER,	/* 1111 */
/* U+2258 */	CANT_MAP_CHARACTER,	/* 1112 */
/* U+2259 */	CANT_MAP_CHARACTER,	/* 1113 */
/* U+225A */	CANT_MAP_CHARACTER,	/* 1114 */
/* U+225B */	CANT_MAP_CHARACTER,	/* 1115 */
/* U+225C */	CANT_MAP_CHARACTER,	/* 1116 */
/* U+225D */	CANT_MAP_CHARACTER,	/* 1117 */
/* U+225E */	CANT_MAP_CHARACTER,	/* 1118 */
/* U+225F */	CANT_MAP_CHARACTER,	/* 1119 */
/* U+2260 */	CANT_MAP_CHARACTER,	/* 1120 */
/* U+2261 */	CANT_MAP_CHARACTER,	/* 1121 */
/* U+2262 */	CANT_MAP_CHARACTER,	/* 1122 */
/* U+2263 */	CANT_MAP_CHARACTER,	/* 1123 */
/* U+2264 */	CANT_MAP_CHARACTER,	/* 1124 */
/* U+2265 */	CANT_MAP_CHARACTER,	/* 1125 */
/* U+2266 */	CANT_MAP_CHARACTER,	/* 1126 */
/* U+2267 */	CANT_MAP_CHARACTER,	/* 1127 */
/* U+2268 */	CANT_MAP_CHARACTER,	/* 1128 */
/* U+2269 */	CANT_MAP_CHARACTER,	/* 1129 */
/* U+226A */	CANT_MAP_CHARACTER,	/* 1130 */
/* U+226B */	CANT_MAP_CHARACTER,	/* 1131 */
/* U+226C */	CANT_MAP_CHARACTER,	/* 1132 */
/* U+226D */	CANT_MAP_CHARACTER,	/* 1133 */
/* U+226E */	CANT_MAP_CHARACTER,	/* 1134 */
/* U+226F */	CANT_MAP_CHARACTER,	/* 1135 */
/* U+2270 */	CANT_MAP_CHARACTER,	/* 1136 */
/* U+2271 */	CANT_MAP_CHARACTER,	/* 1137 */
/* U+2272 */	CANT_MAP_CHARACTER,	/* 1138 */
/* U+2273 */	CANT_MAP_CHARACTER,	/* 1139 */
/* U+2274 */	CANT_MAP_CHARACTER,	/* 1140 */
/* U+2275 */	CANT_MAP_CHARACTER,	/* 1141 */
/* U+2276 */	CANT_MAP_CHARACTER,	/* 1142 */
/* U+2277 */	CANT_MAP_CHARACTER,	/* 1143 */
/* U+2278 */	CANT_MAP_CHARACTER,	/* 1144 */
/* U+2279 */	CANT_MAP_CHARACTER,	/* 1145 */
/* U+227A */	CANT_MAP_CHARACTER,	/* 1146 */
/* U+227B */	CANT_MAP_CHARACTER,	/* 1147 */
/* U+227C */	CANT_MAP_CHARACTER,	/* 1148 */
/* U+227D */	CANT_MAP_CHARACTER,	/* 1149 */
/* U+227E */	CANT_MAP_CHARACTER,	/* 1150 */
/* U+227F */	CANT_MAP_CHARACTER,	/* 1151 */
/* U+2280 */	CANT_MAP_CHARACTER,	/* 1152 */
/* U+2281 */	CANT_MAP_CHARACTER,	/* 1153 */
/* U+2282 */	CANT_MAP_CHARACTER,	/* 1154 */
/* U+2283 */	CANT_MAP_CHARACTER,	/* 1155 */
/* U+2284 */	CANT_MAP_CHARACTER,	/* 1156 */
/* U+2285 */	CANT_MAP_CHARACTER,	/* 1157 */
/* U+2286 */	CANT_MAP_CHARACTER,	/* 1158 */
/* U+2287 */	CANT_MAP_CHARACTER,	/* 1159 */
/* U+2288 */	CANT_MAP_CHARACTER,	/* 1160 */
/* U+2289 */	CANT_MAP_CHARACTER,	/* 1161 */
/* U+228A */	CANT_MAP_CHARACTER,	/* 1162 */
/* U+228B */	CANT_MAP_CHARACTER,	/* 1163 */
/* U+228C */	CANT_MAP_CHARACTER,	/* 1164 */
/* U+228D */	CANT_MAP_CHARACTER,	/* 1165 */
/* U+228E */	CANT_MAP_CHARACTER,	/* 1166 */
/* U+228F */	CANT_MAP_CHARACTER,	/* 1167 */
/* U+2290 */	CANT_MAP_CHARACTER,	/* 1168 */
/* U+2291 */	CANT_MAP_CHARACTER,	/* 1169 */
/* U+2292 */	CANT_MAP_CHARACTER,	/* 1170 */
/* U+2293 */	CANT_MAP_CHARACTER,	/* 1171 */
/* U+2294 */	CANT_MAP_CHARACTER,	/* 1172 */
/* U+2295 */	CANT_MAP_CHARACTER,	/* 1173 */
/* U+2296 */	CANT_MAP_CHARACTER,	/* 1174 */
/* U+2297 */	CANT_MAP_CHARACTER,	/* 1175 */
/* U+2298 */	CANT_MAP_CHARACTER,	/* 1176 */
/* U+2299 */	CANT_MAP_CHARACTER,	/* 1177 */
/* U+229A */	CANT_MAP_CHARACTER,	/* 1178 */
/* U+229B */	CANT_MAP_CHARACTER,	/* 1179 */
/* U+229C */	CANT_MAP_CHARACTER,	/* 1180 */
/* U+229D */	CANT_MAP_CHARACTER,	/* 1181 */
/* U+229E */	CANT_MAP_CHARACTER,	/* 1182 */
/* U+229F */	CANT_MAP_CHARACTER,	/* 1183 */
/* U+22A0 */	CANT_MAP_CHARACTER,	/* 1184 */
/* U+22A1 */	CANT_MAP_CHARACTER,	/* 1185 */
/* U+22A2 */	CANT_MAP_CHARACTER,	/* 1186 */
/* U+22A3 */	CANT_MAP_CHARACTER,	/* 1187 */
/* U+22A4 */	CANT_MAP_CHARACTER,	/* 1188 */
/* U+22A5 */	CANT_MAP_CHARACTER,	/* 1189 */
/* U+22A6 */	CANT_MAP_CHARACTER,	/* 1190 */
/* U+22A7 */	CANT_MAP_CHARACTER,	/* 1191 */
/* U+22A8 */	CANT_MAP_CHARACTER,	/* 1192 */
/* U+22A9 */	CANT_MAP_CHARACTER,	/* 1193 */
/* U+22AA */	CANT_MAP_CHARACTER,	/* 1194 */
/* U+22AB */	CANT_MAP_CHARACTER,	/* 1195 */
/* U+22AC */	CANT_MAP_CHARACTER,	/* 1196 */
/* U+22AD */	CANT_MAP_CHARACTER,	/* 1197 */
/* U+22AE */	CANT_MAP_CHARACTER,	/* 1198 */
/* U+22AF */	CANT_MAP_CHARACTER,	/* 1199 */
/* U+22B0 */	CANT_MAP_CHARACTER,	/* 1200 */
/* U+22B1 */	CANT_MAP_CHARACTER,	/* 1201 */
/* U+22B2 */	CANT_MAP_CHARACTER,	/* 1202 */
/* U+22B3 */	CANT_MAP_CHARACTER,	/* 1203 */
/* U+22B4 */	CANT_MAP_CHARACTER,	/* 1204 */
/* U+22B5 */	CANT_MAP_CHARACTER,	/* 1205 */
/* U+22B6 */	CANT_MAP_CHARACTER,	/* 1206 */
/* U+22B7 */	CANT_MAP_CHARACTER,	/* 1207 */
/* U+22B8 */	CANT_MAP_CHARACTER,	/* 1208 */
/* U+22B9 */	CANT_MAP_CHARACTER,	/* 1209 */
/* U+22BA */	CANT_MAP_CHARACTER,	/* 1210 */
/* U+22BB */	CANT_MAP_CHARACTER,	/* 1211 */
/* U+22BC */	CANT_MAP_CHARACTER,	/* 1212 */
/* U+22BD */	CANT_MAP_CHARACTER,	/* 1213 */
/* U+22BE */	CANT_MAP_CHARACTER,	/* 1214 */
/* U+22BF */	CANT_MAP_CHARACTER,	/* 1215 */
/* U+22C0 */	CANT_MAP_CHARACTER,	/* 1216 */
/* U+22C1 */	CANT_MAP_CHARACTER,	/* 1217 */
/* U+22C2 */	CANT_MAP_CHARACTER,	/* 1218 */
/* U+22C3 */	CANT_MAP_CHARACTER,	/* 1219 */
/* U+22C4 */	CANT_MAP_CHARACTER,	/* 1220 */
/* U+22C5 */	CANT_MAP_CHARACTER,	/* 1221 */
/* U+22C6 */	CANT_MAP_CHARACTER,	/* 1222 */
/* U+22C7 */	CANT_MAP_CHARACTER,	/* 1223 */
/* U+22C8 */	CANT_MAP_CHARACTER,	/* 1224 */
/* U+22C9 */	CANT_MAP_CHARACTER,	/* 1225 */
/* U+22CA */	CANT_MAP_CHARACTER,	/* 1226 */
/* U+22CB */	CANT_MAP_CHARACTER,	/* 1227 */
/* U+22CC */	CANT_MAP_CHARACTER,	/* 1228 */
/* U+22CD */	CANT_MAP_CHARACTER,	/* 1229 */
/* U+22CE */	CANT_MAP_CHARACTER,	/* 1230 */
/* U+22CF */	CANT_MAP_CHARACTER,	/* 1231 */
/* U+22D0 */	CANT_MAP_CHARACTER,	/* 1232 */
/* U+22D1 */	CANT_MAP_CHARACTER,	/* 1233 */
/* U+22D2 */	CANT_MAP_CHARACTER,	/* 1234 */
/* U+22D3 */	CANT_MAP_CHARACTER,	/* 1235 */
/* U+22D4 */	CANT_MAP_CHARACTER,	/* 1236 */
/* U+22D5 */	CANT_MAP_CHARACTER,	/* 1237 */
/* U+22D6 */	CANT_MAP_CHARACTER,	/* 1238 */
/* U+22D7 */	CANT_MAP_CHARACTER,	/* 1239 */
/* U+22D8 */	CANT_MAP_CHARACTER,	/* 1240 */
/* U+22D9 */	CANT_MAP_CHARACTER,	/* 1241 */
/* U+22DA */	CANT_MAP_CHARACTER,	/* 1242 */
/* U+22DB */	CANT_MAP_CHARACTER,	/* 1243 */
/* U+22DC */	CANT_MAP_CHARACTER,	/* 1244 */
/* U+22DD */	CANT_MAP_CHARACTER,	/* 1245 */
/* U+22DE */	CANT_MAP_CHARACTER,	/* 1246 */
/* U+22DF */	CANT_MAP_CHARACTER,	/* 1247 */
/* U+22E0 */	CANT_MAP_CHARACTER,	/* 1248 */
/* U+22E1 */	CANT_MAP_CHARACTER,	/* 1249 */
/* U+22E2 */	CANT_MAP_CHARACTER,	/* 1250 */
/* U+22E3 */	CANT_MAP_CHARACTER,	/* 1251 */
/* U+22E4 */	CANT_MAP_CHARACTER,	/* 1252 */
/* U+22E5 */	CANT_MAP_CHARACTER,	/* 1253 */
/* U+22E6 */	CANT_MAP_CHARACTER,	/* 1254 */
/* U+22E7 */	CANT_MAP_CHARACTER,	/* 1255 */
/* U+22E8 */	CANT_MAP_CHARACTER,	/* 1256 */
/* U+22E9 */	CANT_MAP_CHARACTER,	/* 1257 */
/* U+22EA */	CANT_MAP_CHARACTER,	/* 1258 */
/* U+22EB */	CANT_MAP_CHARACTER,	/* 1259 */
/* U+22EC */	CANT_MAP_CHARACTER,	/* 1260 */
/* U+22ED */	CANT_MAP_CHARACTER,	/* 1261 */
/* U+22EE */	CANT_MAP_CHARACTER,	/* 1262 */
/* U+22EF */	CANT_MAP_CHARACTER,	/* 1263 */
/* U+22F0 */	CANT_MAP_CHARACTER,	/* 1264 */
/* U+22F1 */	CANT_MAP_CHARACTER,	/* 1265 */
/* U+22F2 */	CANT_MAP_CHARACTER,	/* 1266 */
/* U+22F3 */	CANT_MAP_CHARACTER,	/* 1267 */
/* U+22F4 */	CANT_MAP_CHARACTER,	/* 1268 */
/* U+22F5 */	CANT_MAP_CHARACTER,	/* 1269 */
/* U+22F6 */	CANT_MAP_CHARACTER,	/* 1270 */
/* U+22F7 */	CANT_MAP_CHARACTER,	/* 1271 */
/* U+22F8 */	CANT_MAP_CHARACTER,	/* 1272 */
/* U+22F9 */	CANT_MAP_CHARACTER,	/* 1273 */
/* U+22FA */	CANT_MAP_CHARACTER,	/* 1274 */
/* U+22FB */	CANT_MAP_CHARACTER,	/* 1275 */
/* U+22FC */	CANT_MAP_CHARACTER,	/* 1276 */
/* U+22FD */	CANT_MAP_CHARACTER,	/* 1277 */
/* U+22FE */	CANT_MAP_CHARACTER,	/* 1278 */
/* U+22FF */	CANT_MAP_CHARACTER,	/* 1279 */
/* U+2500 */	0xC4	/*                 BOX DRAWINGS LIGHT HORIZONTAL */,/* 1280 */
/* U+2501 */	CANT_MAP_CHARACTER,	/* 1281 */
/* U+2502 */	0xB3	/*                   BOX DRAWINGS LIGHT VERTICAL */,/* 1282 */
/* U+2503 */	CANT_MAP_CHARACTER,	/* 1283 */
/* U+2504 */	CANT_MAP_CHARACTER,	/* 1284 */
/* U+2505 */	CANT_MAP_CHARACTER,	/* 1285 */
/* U+2506 */	CANT_MAP_CHARACTER,	/* 1286 */
/* U+2507 */	CANT_MAP_CHARACTER,	/* 1287 */
/* U+2508 */	CANT_MAP_CHARACTER,	/* 1288 */
/* U+2509 */	CANT_MAP_CHARACTER,	/* 1289 */
/* U+250A */	CANT_MAP_CHARACTER,	/* 1290 */
/* U+250B */	CANT_MAP_CHARACTER,	/* 1291 */
/* U+250C */	0xDA	/*             BOX DRAWINGS LIGHT DOWN AND RIGHT */,/* 1292 */
/* U+250D */	CANT_MAP_CHARACTER,	/* 1293 */
/* U+250E */	CANT_MAP_CHARACTER,	/* 1294 */
/* U+250F */	CANT_MAP_CHARACTER,	/* 1295 */
/* U+2510 */	0xBF	/*              BOX DRAWINGS LIGHT DOWN AND LEFT */,/* 1296 */
/* U+2511 */	CANT_MAP_CHARACTER,	/* 1297 */
/* U+2512 */	CANT_MAP_CHARACTER,	/* 1298 */
/* U+2513 */	CANT_MAP_CHARACTER,	/* 1299 */
/* U+2514 */	0xC0	/*               BOX DRAWINGS LIGHT UP AND RIGHT */,/* 1300 */
/* U+2515 */	CANT_MAP_CHARACTER,	/* 1301 */
/* U+2516 */	CANT_MAP_CHARACTER,	/* 1302 */
/* U+2517 */	CANT_MAP_CHARACTER,	/* 1303 */
/* U+2518 */	0xD9	/*                BOX DRAWINGS LIGHT UP AND LEFT */,/* 1304 */
/* U+2519 */	CANT_MAP_CHARACTER,	/* 1305 */
/* U+251A */	CANT_MAP_CHARACTER,	/* 1306 */
/* U+251B */	CANT_MAP_CHARACTER,	/* 1307 */
/* U+251C */	0xC3	/*         BOX DRAWINGS LIGHT VERTICAL AND RIGHT */,/* 1308 */
/* U+251D */	CANT_MAP_CHARACTER,	/* 1309 */
/* U+251E */	CANT_MAP_CHARACTER,	/* 1310 */
/* U+251F */	CANT_MAP_CHARACTER,	/* 1311 */
/* U+2520 */	CANT_MAP_CHARACTER,	/* 1312 */
/* U+2521 */	CANT_MAP_CHARACTER,	/* 1313 */
/* U+2522 */	CANT_MAP_CHARACTER,	/* 1314 */
/* U+2523 */	CANT_MAP_CHARACTER,	/* 1315 */
/* U+2524 */	0xB4	/*          BOX DRAWINGS LIGHT VERTICAL AND LEFT */,/* 1316 */
/* U+2525 */	CANT_MAP_CHARACTER,	/* 1317 */
/* U+2526 */	CANT_MAP_CHARACTER,	/* 1318 */
/* U+2527 */	CANT_MAP_CHARACTER,	/* 1319 */
/* U+2528 */	CANT_MAP_CHARACTER,	/* 1320 */
/* U+2529 */	CANT_MAP_CHARACTER,	/* 1321 */
/* U+252A */	CANT_MAP_CHARACTER,	/* 1322 */
/* U+252B */	CANT_MAP_CHARACTER,	/* 1323 */
/* U+252C */	0xC2	/*        BOX DRAWINGS LIGHT DOWN AND HORIZONTAL */,/* 1324 */
/* U+252D */	CANT_MAP_CHARACTER,	/* 1325 */
/* U+252E */	CANT_MAP_CHARACTER,	/* 1326 */
/* U+252F */	CANT_MAP_CHARACTER,	/* 1327 */
/* U+2530 */	CANT_MAP_CHARACTER,	/* 1328 */
/* U+2531 */	CANT_MAP_CHARACTER,	/* 1329 */
/* U+2532 */	CANT_MAP_CHARACTER,	/* 1330 */
/* U+2533 */	CANT_MAP_CHARACTER,	/* 1331 */
/* U+2534 */	0xC1	/*          BOX DRAWINGS LIGHT UP AND HORIZONTAL */,/* 1332 */
/* U+2535 */	CANT_MAP_CHARACTER,	/* 1333 */
/* U+2536 */	CANT_MAP_CHARACTER,	/* 1334 */
/* U+2537 */	CANT_MAP_CHARACTER,	/* 1335 */
/* U+2538 */	CANT_MAP_CHARACTER,	/* 1336 */
/* U+2539 */	CANT_MAP_CHARACTER,	/* 1337 */
/* U+253A */	CANT_MAP_CHARACTER,	/* 1338 */
/* U+253B */	CANT_MAP_CHARACTER,	/* 1339 */
/* U+253C */	0xC5	/*    BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL */,/* 1340 */
/* U+253D */	CANT_MAP_CHARACTER,	/* 1341 */
/* U+253E */	CANT_MAP_CHARACTER,	/* 1342 */
/* U+253F */	CANT_MAP_CHARACTER,	/* 1343 */
/* U+2540 */	CANT_MAP_CHARACTER,	/* 1344 */
/* U+2541 */	CANT_MAP_CHARACTER,	/* 1345 */
/* U+2542 */	CANT_MAP_CHARACTER,	/* 1346 */
/* U+2543 */	CANT_MAP_CHARACTER,	/* 1347 */
/* U+2544 */	CANT_MAP_CHARACTER,	/* 1348 */
/* U+2545 */	CANT_MAP_CHARACTER,	/* 1349 */
/* U+2546 */	CANT_MAP_CHARACTER,	/* 1350 */
/* U+2547 */	CANT_MAP_CHARACTER,	/* 1351 */
/* U+2548 */	CANT_MAP_CHARACTER,	/* 1352 */
/* U+2549 */	CANT_MAP_CHARACTER,	/* 1353 */
/* U+254A */	CANT_MAP_CHARACTER,	/* 1354 */
/* U+254B */	CANT_MAP_CHARACTER,	/* 1355 */
/* U+254C */	CANT_MAP_CHARACTER,	/* 1356 */
/* U+254D */	CANT_MAP_CHARACTER,	/* 1357 */
/* U+254E */	CANT_MAP_CHARACTER,	/* 1358 */
/* U+254F */	CANT_MAP_CHARACTER,	/* 1359 */
/* U+2550 */	0xCD	/*                BOX DRAWINGS DOUBLE HORIZONTAL */,/* 1360 */
/* U+2551 */	0xBA	/*                  BOX DRAWINGS DOUBLE VERTICAL */,/* 1361 */
/* U+2552 */	0xD5	/*     BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE */,/* 1362 */
/* U+2553 */	0xD6	/*     BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE */,/* 1363 */
/* U+2554 */	0xC9	/*            BOX DRAWINGS DOUBLE DOWN AND RIGHT */,/* 1364 */
/* U+2555 */	0xB8	/*      BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE */,/* 1365 */
/* U+2556 */	0xB7	/*      BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE */,/* 1366 */
/* U+2557 */	0xBB	/*             BOX DRAWINGS DOUBLE DOWN AND LEFT */,/* 1367 */
/* U+2558 */	0xD4	/*       BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE */,/* 1368 */
/* U+2559 */	0xD3	/*       BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE */,/* 1369 */
/* U+255A */	0xC8	/*              BOX DRAWINGS DOUBLE UP AND RIGHT */,/* 1370 */
/* U+255B */	0xBE	/*        BOX DRAWINGS UP SINGLE AND LEFT DOUBLE */,/* 1371 */
/* U+255C */	0xBD	/*        BOX DRAWINGS UP DOUBLE AND LEFT SINGLE */,/* 1372 */
/* U+255D */	0xBC	/*               BOX DRAWINGS DOUBLE UP AND LEFT */,/* 1373 */
/* U+255E */	0xC6	/* BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE */,/* 1374 */
/* U+255F */	0xC7	/* BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE */,/* 1375 */
/* U+2560 */	0xCC	/*        BOX DRAWINGS DOUBLE VERTICAL AND RIGHT */,/* 1376 */
/* U+2561 */	0xB5	/*  BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE */,/* 1377 */
/* U+2562 */	0xB6	/*  BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE */,/* 1378 */
/* U+2563 */	0xB9	/*         BOX DRAWINGS DOUBLE VERTICAL AND LEFT */,/* 1379 */
/* U+2564 */	0xD1	/* BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE */,/* 1380 */
/* U+2565 */	0xD2	/* BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE */,/* 1381 */
/* U+2566 */	0xCB	/*       BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL */,/* 1382 */
/* U+2567 */	0xCF	/*  BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE */,/* 1383 */
/* U+2568 */	0xD0	/*  BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE */,/* 1384 */
/* U+2569 */	0xCA	/*         BOX DRAWINGS DOUBLE UP AND HORIZONTAL */,/* 1385 */
/* U+256A */	0xD8	/* BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE */,/* 1386 */
/* U+256B */	0xD7	/* BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE */,/* 1387 */
/* U+256C */	0xCE	/*   BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL */,/* 1388 */
/* U+256D */	CANT_MAP_CHARACTER,	/* 1389 */
/* U+256E */	CANT_MAP_CHARACTER,	/* 1390 */
/* U+256F */	CANT_MAP_CHARACTER,	/* 1391 */
/* U+2570 */	CANT_MAP_CHARACTER,	/* 1392 */
/* U+2571 */	CANT_MAP_CHARACTER,	/* 1393 */
/* U+2572 */	CANT_MAP_CHARACTER,	/* 1394 */
/* U+2573 */	CANT_MAP_CHARACTER,	/* 1395 */
/* U+2574 */	CANT_MAP_CHARACTER,	/* 1396 */
/* U+2575 */	CANT_MAP_CHARACTER,	/* 1397 */
/* U+2576 */	CANT_MAP_CHARACTER,	/* 1398 */
/* U+2577 */	CANT_MAP_CHARACTER,	/* 1399 */
/* U+2578 */	CANT_MAP_CHARACTER,	/* 1400 */
/* U+2579 */	CANT_MAP_CHARACTER,	/* 1401 */
/* U+257A */	CANT_MAP_CHARACTER,	/* 1402 */
/* U+257B */	CANT_MAP_CHARACTER,	/* 1403 */
/* U+257C */	CANT_MAP_CHARACTER,	/* 1404 */
/* U+257D */	CANT_MAP_CHARACTER,	/* 1405 */
/* U+257E */	CANT_MAP_CHARACTER,	/* 1406 */
/* U+257F */	CANT_MAP_CHARACTER,	/* 1407 */
/* U+2580 */	0xDF	/*                              UPPER HALF BLOCK */,/* 1408 */
/* U+2581 */	CANT_MAP_CHARACTER,	/* 1409 */
/* U+2582 */	CANT_MAP_CHARACTER,	/* 1410 */
/* U+2583 */	CANT_MAP_CHARACTER,	/* 1411 */
/* U+2584 */	0xDC	/*                              LOWER HALF BLOCK */,/* 1412 */
/* U+2585 */	CANT_MAP_CHARACTER,	/* 1413 */
/* U+2586 */	CANT_MAP_CHARACTER,	/* 1414 */
/* U+2587 */	CANT_MAP_CHARACTER,	/* 1415 */
/* U+2588 */	0xDB	/*                                    FULL BLOCK */,/* 1416 */
/* U+2589 */	CANT_MAP_CHARACTER,	/* 1417 */
/* U+258A */	CANT_MAP_CHARACTER,	/* 1418 */
/* U+258B */	CANT_MAP_CHARACTER,	/* 1419 */
/* U+258C */	0xDD	/*                               LEFT HALF BLOCK */,/* 1420 */
/* U+258D */	CANT_MAP_CHARACTER,	/* 1421 */
/* U+258E */	CANT_MAP_CHARACTER,	/* 1422 */
/* U+258F */	CANT_MAP_CHARACTER,	/* 1423 */
/* U+2590 */	0xDE	/*                              RIGHT HALF BLOCK */,/* 1424 */
/* U+2591 */	0xB0	/*                                   LIGHT SHADE */,/* 1425 */
/* U+2592 */	0xB1	/*                                  MEDIUM SHADE */,/* 1426 */
/* U+2593 */	0xB2	/*                                    DARK SHADE */,/* 1427 */
/* U+2594 */	CANT_MAP_CHARACTER,	/* 1428 */
/* U+2595 */	CANT_MAP_CHARACTER,	/* 1429 */
/* U+2596 */	CANT_MAP_CHARACTER,	/* 1430 */
/* U+2597 */	CANT_MAP_CHARACTER,	/* 1431 */
/* U+2598 */	CANT_MAP_CHARACTER,	/* 1432 */
/* U+2599 */	CANT_MAP_CHARACTER,	/* 1433 */
/* U+259A */	CANT_MAP_CHARACTER,	/* 1434 */
/* U+259B */	CANT_MAP_CHARACTER,	/* 1435 */
/* U+259C */	CANT_MAP_CHARACTER,	/* 1436 */
/* U+259D */	CANT_MAP_CHARACTER,	/* 1437 */
/* U+259E */	CANT_MAP_CHARACTER,	/* 1438 */
/* U+259F */	CANT_MAP_CHARACTER,	/* 1439 */
/* U+25A0 */	0xFE	/*                                  BLACK SQUARE */,/* 1440 */
/* U+25A1 */	CANT_MAP_CHARACTER,	/* 1441 */
/* U+25A2 */	CANT_MAP_CHARACTER,	/* 1442 */
/* U+25A3 */	CANT_MAP_CHARACTER,	/* 1443 */
/* U+25A4 */	CANT_MAP_CHARACTER,	/* 1444 */
/* U+25A5 */	CANT_MAP_CHARACTER,	/* 1445 */
/* U+25A6 */	CANT_MAP_CHARACTER,	/* 1446 */
/* U+25A7 */	CANT_MAP_CHARACTER,	/* 1447 */
/* U+25A8 */	CANT_MAP_CHARACTER,	/* 1448 */
/* U+25A9 */	CANT_MAP_CHARACTER,	/* 1449 */
/* U+25AA */	CANT_MAP_CHARACTER,	/* 1450 */
/* U+25AB */	CANT_MAP_CHARACTER,	/* 1451 */
/* U+25AC */	CANT_MAP_CHARACTER,	/* 1452 */
/* U+25AD */	CANT_MAP_CHARACTER,	/* 1453 */
/* U+25AE */	CANT_MAP_CHARACTER,	/* 1454 */
/* U+25AF */	CANT_MAP_CHARACTER,	/* 1455 */
/* U+25B0 */	CANT_MAP_CHARACTER,	/* 1456 */
/* U+25B1 */	CANT_MAP_CHARACTER,	/* 1457 */
/* U+25B2 */	CANT_MAP_CHARACTER,	/* 1458 */
/* U+25B3 */	CANT_MAP_CHARACTER,	/* 1459 */
/* U+25B4 */	CANT_MAP_CHARACTER,	/* 1460 */
/* U+25B5 */	CANT_MAP_CHARACTER,	/* 1461 */
/* U+25B6 */	CANT_MAP_CHARACTER,	/* 1462 */
/* U+25B7 */	CANT_MAP_CHARACTER,	/* 1463 */
/* U+25B8 */	CANT_MAP_CHARACTER,	/* 1464 */
/* U+25B9 */	CANT_MAP_CHARACTER,	/* 1465 */
/* U+25BA */	CANT_MAP_CHARACTER,	/* 1466 */
/* U+25BB */	CANT_MAP_CHARACTER,	/* 1467 */
/* U+25BC */	CANT_MAP_CHARACTER,	/* 1468 */
/* U+25BD */	CANT_MAP_CHARACTER,	/* 1469 */
/* U+25BE */	CANT_MAP_CHARACTER,	/* 1470 */
/* U+25BF */	CANT_MAP_CHARACTER,	/* 1471 */
/* U+25C0 */	CANT_MAP_CHARACTER,	/* 1472 */
/* U+25C1 */	CANT_MAP_CHARACTER,	/* 1473 */
/* U+25C2 */	CANT_MAP_CHARACTER,	/* 1474 */
/* U+25C3 */	CANT_MAP_CHARACTER,	/* 1475 */
/* U+25C4 */	CANT_MAP_CHARACTER,	/* 1476 */
/* U+25C5 */	CANT_MAP_CHARACTER,	/* 1477 */
/* U+25C6 */	CANT_MAP_CHARACTER,	/* 1478 */
/* U+25C7 */	CANT_MAP_CHARACTER,	/* 1479 */
/* U+25C8 */	CANT_MAP_CHARACTER,	/* 1480 */
/* U+25C9 */	CANT_MAP_CHARACTER,	/* 1481 */
/* U+25CA */	CANT_MAP_CHARACTER,	/* 1482 */
/* U+25CB */	CANT_MAP_CHARACTER,	/* 1483 */
/* U+25CC */	CANT_MAP_CHARACTER,	/* 1484 */
/* U+25CD */	CANT_MAP_CHARACTER,	/* 1485 */
/* U+25CE */	CANT_MAP_CHARACTER,	/* 1486 */
/* U+25CF */	CANT_MAP_CHARACTER,	/* 1487 */
/* U+25D0 */	CANT_MAP_CHARACTER,	/* 1488 */
/* U+25D1 */	CANT_MAP_CHARACTER,	/* 1489 */
/* U+25D2 */	CANT_MAP_CHARACTER,	/* 1490 */
/* U+25D3 */	CANT_MAP_CHARACTER,	/* 1491 */
/* U+25D4 */	CANT_MAP_CHARACTER,	/* 1492 */
/* U+25D5 */	CANT_MAP_CHARACTER,	/* 1493 */
/* U+25D6 */	CANT_MAP_CHARACTER,	/* 1494 */
/* U+25D7 */	CANT_MAP_CHARACTER,	/* 1495 */
/* U+25D8 */	CANT_MAP_CHARACTER,	/* 1496 */
/* U+25D9 */	CANT_MAP_CHARACTER,	/* 1497 */
/* U+25DA */	CANT_MAP_CHARACTER,	/* 1498 */
/* U+25DB */	CANT_MAP_CHARACTER,	/* 1499 */
/* U+25DC */	CANT_MAP_CHARACTER,	/* 1500 */
/* U+25DD */	CANT_MAP_CHARACTER,	/* 1501 */
/* U+25DE */	CANT_MAP_CHARACTER,	/* 1502 */
/* U+25DF */	CANT_MAP_CHARACTER,	/* 1503 */
/* U+25E0 */	CANT_MAP_CHARACTER,	/* 1504 */
/* U+25E1 */	CANT_MAP_CHARACTER,	/* 1505 */
/* U+25E2 */	CANT_MAP_CHARACTER,	/* 1506 */
/* U+25E3 */	CANT_MAP_CHARACTER,	/* 1507 */
/* U+25E4 */	CANT_MAP_CHARACTER,	/* 1508 */
/* U+25E5 */	CANT_MAP_CHARACTER,	/* 1509 */
/* U+25E6 */	CANT_MAP_CHARACTER,	/* 1510 */
/* U+25E7 */	CANT_MAP_CHARACTER,	/* 1511 */
/* U+25E8 */	CANT_MAP_CHARACTER,	/* 1512 */
/* U+25E9 */	CANT_MAP_CHARACTER,	/* 1513 */
/* U+25EA */	CANT_MAP_CHARACTER,	/* 1514 */
/* U+25EB */	CANT_MAP_CHARACTER,	/* 1515 */
/* U+25EC */	CANT_MAP_CHARACTER,	/* 1516 */
/* U+25ED */	CANT_MAP_CHARACTER,	/* 1517 */
/* U+25EE */	CANT_MAP_CHARACTER,	/* 1518 */
/* U+25EF */	CANT_MAP_CHARACTER,	/* 1519 */
/* U+25F0 */	CANT_MAP_CHARACTER,	/* 1520 */
/* U+25F1 */	CANT_MAP_CHARACTER,	/* 1521 */
/* U+25F2 */	CANT_MAP_CHARACTER,	/* 1522 */
/* U+25F3 */	CANT_MAP_CHARACTER,	/* 1523 */
/* U+25F4 */	CANT_MAP_CHARACTER,	/* 1524 */
/* U+25F5 */	CANT_MAP_CHARACTER,	/* 1525 */
/* U+25F6 */	CANT_MAP_CHARACTER,	/* 1526 */
/* U+25F7 */	CANT_MAP_CHARACTER,	/* 1527 */
/* U+25F8 */	CANT_MAP_CHARACTER,	/* 1528 */
/* U+25F9 */	CANT_MAP_CHARACTER,	/* 1529 */
/* U+25FA */	CANT_MAP_CHARACTER,	/* 1530 */
/* U+25FB */	CANT_MAP_CHARACTER,	/* 1531 */
/* U+25FC */	CANT_MAP_CHARACTER,	/* 1532 */
/* U+25FD */	CANT_MAP_CHARACTER,	/* 1533 */
/* U+25FE */	CANT_MAP_CHARACTER,	/* 1534 */
/* U+25FF */	CANT_MAP_CHARACTER,	/* 1535 */
	0 /* END OF MAP TABLE */
};
static const USHORT from_unicode_map[256] = {
/* U+00-- */	256,
/* U+01-- */	0,
/* U+02-- */	0,
/* U+03-- */	0,
/* U+04-- */	512,
/* U+05-- */	0,
/* U+06-- */	0,
/* U+07-- */	0,
/* U+08-- */	0,
/* U+09-- */	0,
/* U+0A-- */	0,
/* U+0B-- */	0,
/* U+0C-- */	0,
/* U+0D-- */	0,
/* U+0E-- */	0,
/* U+0F-- */	0,
/* U+10-- */	0,
/* U+11-- */	0,
/* U+12-- */	0,
/* U+13-- */	0,
/* U+14-- */	0,
/* U+15-- */	0,
/* U+16-- */	0,
/* U+17-- */	0,
/* U+18-- */	0,
/* U+19-- */	0,
/* U+1A-- */	0,
/* U+1B-- */	0,
/* U+1C-- */	0,
/* U+1D-- */	0,
/* U+1E-- */	0,
/* U+1F-- */	0,
/* U+20-- */	0,
/* U+21-- */	768,
/* U+22-- */	1024,
/* U+23-- */	0,
/* U+24-- */	0,
/* U+25-- */	1280,
/* U+26-- */	0,
/* U+27-- */	0,
/* U+28-- */	0,
/* U+29-- */	0,
/* U+2A-- */	0,
/* U+2B-- */	0,
/* U+2C-- */	0,
/* U+2D-- */	0,
/* U+2E-- */	0,
/* U+2F-- */	0,
/* U+30-- */	0,
/* U+31-- */	0,
/* U+32-- */	0,
/* U+33-- */	0,
/* U+34-- */	0,
/* U+35-- */	0,
/* U+36-- */	0,
/* U+37-- */	0,
/* U+38-- */	0,
/* U+39-- */	0,
/* U+3A-- */	0,
/* U+3B-- */	0,
/* U+3C-- */	0,
/* U+3D-- */	0,
/* U+3E-- */	0,
/* U+3F-- */	0,
/* U+40-- */	0,
/* U+41-- */	0,
/* U+42-- */	0,
/* U+43-- */	0,
/* U+44-- */	0,
/* U+45-- */	0,
/* U+46-- */	0,
/* U+47-- */	0,
/* U+48-- */	0,
/* U+49-- */	0,
/* U+4A-- */	0,
/* U+4B-- */	0,
/* U+4C-- */	0,
/* U+4D-- */	0,
/* U+4E-- */	0,
/* U+4F-- */	0,
/* U+50-- */	0,
/* U+51-- */	0,
/* U+52-- */	0,
/* U+53-- */	0,
/* U+54-- */	0,
/* U+55-- */	0,
/* U+56-- */	0,
/* U+57-- */	0,
/* U+58-- */	0,
/* U+59-- */	0,
/* U+5A-- */	0,
/* U+5B-- */	0,
/* U+5C-- */	0,
/* U+5D-- */	0,
/* U+5E-- */	0,
/* U+5F-- */	0,
/* U+60-- */	0,
/* U+61-- */	0,
/* U+62-- */	0,
/* U+63-- */	0,
/* U+64-- */	0,
/* U+65-- */	0,
/* U+66-- */	0,
/* U+67-- */	0,
/* U+68-- */	0,
/* U+69-- */	0,
/* U+6A-- */	0,
/* U+6B-- */	0,
/* U+6C-- */	0,
/* U+6D-- */	0,
/* U+6E-- */	0,
/* U+6F-- */	0,
/* U+70-- */	0,
/* U+71-- */	0,
/* U+72-- */	0,
/* U+73-- */	0,
/* U+74-- */	0,
/* U+75-- */	0,
/* U+76-- */	0,
/* U+77-- */	0,
/* U+78-- */	0,
/* U+79-- */	0,
/* U+7A-- */	0,
/* U+7B-- */	0,
/* U+7C-- */	0,
/* U+7D-- */	0,
/* U+7E-- */	0,
/* U+7F-- */	0,
/* U+80-- */	0,
/* U+81-- */	0,
/* U+82-- */	0,
/* U+83-- */	0,
/* U+84-- */	0,
/* U+85-- */	0,
/* U+86-- */	0,
/* U+87-- */	0,
/* U+88-- */	0,
/* U+89-- */	0,
/* U+8A-- */	0,
/* U+8B-- */	0,
/* U+8C-- */	0,
/* U+8D-- */	0,
/* U+8E-- */	0,
/* U+8F-- */	0,
/* U+90-- */	0,
/* U+91-- */	0,
/* U+92-- */	0,
/* U+93-- */	0,
/* U+94-- */	0,
/* U+95-- */	0,
/* U+96-- */	0,
/* U+97-- */	0,
/* U+98-- */	0,
/* U+99-- */	0,
/* U+9A-- */	0,
/* U+9B-- */	0,
/* U+9C-- */	0,
/* U+9D-- */	0,
/* U+9E-- */	0,
/* U+9F-- */	0,
/* U+A0-- */	0,
/* U+A1-- */	0,
/* U+A2-- */	0,
/* U+A3-- */	0,
/* U+A4-- */	0,
/* U+A5-- */	0,
/* U+A6-- */	0,
/* U+A7-- */	0,
/* U+A8-- */	0,
/* U+A9-- */	0,
/* U+AA-- */	0,
/* U+AB-- */	0,
/* U+AC-- */	0,
/* U+AD-- */	0,
/* U+AE-- */	0,
/* U+AF-- */	0,
/* U+B0-- */	0,
/* U+B1-- */	0,
/* U+B2-- */	0,
/* U+B3-- */	0,
/* U+B4-- */	0,
/* U+B5-- */	0,
/* U+B6-- */	0,
/* U+B7-- */	0,
/* U+B8-- */	0,
/* U+B9-- */	0,
/* U+BA-- */	0,
/* U+BB-- */	0,
/* U+BC-- */	0,
/* U+BD-- */	0,
/* U+BE-- */	0,
/* U+BF-- */	0,
/* U+C0-- */	0,
/* U+C1-- */	0,
/* U+C2-- */	0,
/* U+C3-- */	0,
/* U+C4-- */	0,
/* U+C5-- */	0,
/* U+C6-- */	0,
/* U+C7-- */	0,
/* U+C8-- */	0,
/* U+C9-- */	0,
/* U+CA-- */	0,
/* U+CB-- */	0,
/* U+CC-- */	0,
/* U+CD-- */	0,
/* U+CE-- */	0,
/* U+CF-- */	0,
/* U+D0-- */	0,
/* U+D1-- */	0,
/* U+D2-- */	0,
/* U+D3-- */	0,
/* U+D4-- */	0,
/* U+D5-- */	0,
/* U+D6-- */	0,
/* U+D7-- */	0,
/* U+D8-- */	0,
/* U+D9-- */	0,
/* U+DA-- */	0,
/* U+DB-- */	0,
/* U+DC-- */	0,
/* U+DD-- */	0,
/* U+DE-- */	0,
/* U+DF-- */	0,
/* U+E0-- */	0,
/* U+E1-- */	0,
/* U+E2-- */	0,
/* U+E3-- */	0,
/* U+E4-- */	0,
/* U+E5-- */	0,
/* U+E6-- */	0,
/* U+E7-- */	0,
/* U+E8-- */	0,
/* U+E9-- */	0,
/* U+EA-- */	0,
/* U+EB-- */	0,
/* U+EC-- */	0,
/* U+ED-- */	0,
/* U+EE-- */	0,
/* U+EF-- */	0,
/* U+F0-- */	0,
/* U+F1-- */	0,
/* U+F2-- */	0,
/* U+F3-- */	0,
/* U+F4-- */	0,
/* U+F5-- */	0,
/* U+F6-- */	0,
/* U+F7-- */	0,
/* U+F8-- */	0,
/* U+F9-- */	0,
/* U+FA-- */	0,
/* U+FB-- */	0,
/* U+FC-- */	0,
/* U+FD-- */	0,
/* U+FE-- */	0,
/* U+FF-- */	0,
};
